import 'package:equatable/equatable.dart';

class BrPlaceMenuContent {
  String? id;
  String? menuTitle;
  String? pictureUrl;
  String? oobrPlaceName;
  String? qrCode;
  List<PlaceMenuMaincats>? maincats;

  BrPlaceMenuContent(
      {this.id, this.menuTitle, this.pictureUrl, this.oobrPlaceName, this.qrCode, this.maincats});

  BrPlaceMenuContent.fromJson(Map<String, dynamic> json) {
    if (json["id"] is String) this.id = json["id"];
    if (json["menuTitle"] is String) this.menuTitle = json["menuTitle"];
    if (json["pictureUrl"] is String) this.pictureUrl = json["pictureUrl"];
    if (json["oobrPlaceName"] is String) this.oobrPlaceName = json["oobrPlaceName"];
    if (json["qrCode"] is String) this.qrCode = json["qrCode"];
    if (json["maincats"] is List)
      this.maincats = json["maincats"] == null
          ? null
          : (json["maincats"] as List).map((e) => PlaceMenuMaincats.fromJson(e)).toList();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data["id"] = this.id;
    data["menuTitle"] = this.menuTitle;
    data["pictureUrl"] = this.pictureUrl;
    data["oobrPlaceName"] = this.oobrPlaceName;
    data["qrCode"] = this.qrCode;
    if (this.maincats != null) data["maincats"] = this.maincats?.map((e) => e.toJson()).toList();
    return data;
  }
}

class PlaceMenuItems extends Equatable {
  String? id;
  int? order;
  String? name;
  String? description;
  String? pictureUrl;
  double? price;
  double? promoPrice;
  String? currency;
  int? orderOnline;
  int? quickOrderInPlace;
  String? qrCode;
  int? hasOptions;

  int quantity = 0;
  bool expand = false;
  List<PlaceMenuAllergens> allergens = [];
  List<PlaceMenuItemOption> options = [];
  List<PlaceMenuItemOption> optionsSelected = [];

  double get realPrice => promoPrice != null && promoPrice! > 0 ? promoPrice! : (price ?? 0.0);

  PlaceMenuItems(
      {this.id,
      this.order,
      this.name,
      this.pictureUrl,
      this.price,
      this.currency,
      this.orderOnline,
      this.quickOrderInPlace,
      this.qrCode,
      this.description,
      this.promoPrice,
      this.hasOptions});

  PlaceMenuItems.fromJson(Map<String, dynamic> json) {
    if (json["id"] is String) this.id = json["id"];
    if (json["order"] is int) this.order = json["order"];
    if (json["name"] is String) this.name = json["name"];
    if (json["description"] is String) this.description = json["description"];
    if (json["pictureUrl"] is String) this.pictureUrl = json["pictureUrl"];
    if (json["price"] is double) this.price = json["price"];
    if (json["promoPrice"] is double) this.promoPrice = json["promoPrice"];
    if (json["currency"] is String) this.currency = json["currency"];
    if (json["orderOnline"] is int) this.orderOnline = json["orderOnline"];
    if (json["quickOrderInPlace"] is int) this.quickOrderInPlace = json["quickOrderInPlace"];
    if (json["hasOptions"] is int) this.hasOptions = json["hasOptions"];
    if (json["qrCode"] is String) this.qrCode = json["qrCode"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data["id"] = this.id;
    data["order"] = this.order;
    data["name"] = this.name;
    data["description"] = this.description;
    data["pictureUrl"] = this.pictureUrl;
    data["price"] = this.price;
    data["promoPrice"] = this.promoPrice;
    data["currency"] = this.currency;
    data["orderOnline"] = this.orderOnline;
    data["quickOrderInPlace"] = this.quickOrderInPlace;
    data["hasOptions"] = this.hasOptions;
    data["qrCode"] = this.qrCode;
    return data;
  }

  @override 
  List<Object?> get props => [optionsSelected, id];
}

class PlaceMenuMaincats {
  String? id;
  int? order;
  String? catName;
  List<PlaceMenuSubcats>? subcats;

  PlaceMenuMaincats({this.id, this.order, this.catName, this.subcats});

  PlaceMenuMaincats.fromJson(Map<String, dynamic> json) {
    if (json["id"] is String) this.id = json["id"];
    if (json["order"] is int) this.order = json["order"];
    if (json["catName"] is String) this.catName = json["catName"];
    if (json["subcats"] is List)
      this.subcats = json["subcats"] == null
          ? null
          : (json["subcats"] as List).map((e) => PlaceMenuSubcats.fromJson(e)).toList();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data["id"] = this.id;
    data["order"] = this.order;
    data["catName"] = this.catName;
    if (this.subcats != null) data["subcats"] = this.subcats?.map((e) => e.toJson()).toList();
    return data;
  }
}

class PlaceMenuSubcats {
  String? id;
  int? order;
  String? catName;
  List<PlaceMenuItems>? items;

  PlaceMenuSubcats({this.id, this.order, this.catName, this.items});

  PlaceMenuSubcats.fromJson(Map<String, dynamic> json) {
    if (json["id"] is String) this.id = json["id"];
    if (json["order"] is int) this.order = json["order"];
    if (json["catName"] is String) this.catName = json["catName"];
    if (json["items"] is List)
      this.items = json["items"] == null
          ? null
          : (json["items"] as List).map((e) => PlaceMenuItems.fromJson(e)).toList();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data["id"] = this.id;
    data["order"] = this.order;
    data["catName"] = this.catName;
    if (this.items != null) data["items"] = this.items?.map((e) => e.toJson()).toList();
    return data;
  }
}

class PlaceMenuItemOption extends Equatable {
  String? id;
  String? currency;
  double? price;
  String? name;
  String? valueName;

  PlaceMenuItemOption({this.id, this.currency, this.price, this.name, this.valueName});

  PlaceMenuItemOption.fromJson(Map<String, dynamic> json) {
    if (json["id"] is String) this.id = json["id"];
    if (json["currency"] is String) this.currency = json["currency"];
    if (json["price"] is double) this.price = json["price"];
    if (json["name"] is String) this.name = json["name"];
    if (json["valueName"] is String) this.valueName = json["valueName"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data["id"] = this.id;
    data["currency"] = this.currency;
    data["price"] = this.price;
    data["name"] = this.name;
    data["valueName"] = this.valueName;
    return data;
  }

  @override 
  List<Object?> get props => [id];
}

class PlaceMenuAllergens {
  String? id;
  String? name;
  String? internationalCode;

  PlaceMenuAllergens({this.id, this.name, this.internationalCode});

  PlaceMenuAllergens.fromJson(Map<String, dynamic> json) {
    if (json["id"] is String) this.id = json["id"];
    if (json["name"] is String) this.name = json["name"];
    if (json["internationalCode"] is String) this.internationalCode = json["internationalCode"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data["id"] = this.id;
    data["name"] = this.name;
    data["internationalCode"] = this.internationalCode;
    return data;
  }
}
