import '../model/_model.dart';

abstract class AppApi {
  /// Auth
  Future<NetworkResponse> refreshUserToken(refreshToken);
  Future<NetworkResponse> refreshProToken(refreshToken);
  Future<NetworkResponse> checkNewPhoneFromUser(phone);
  Future<NetworkResponse> checkNewPhoneFromPro(phone);
  Future<NetworkResponse> checkExistPhoneFromUser(phone);
  Future<NetworkResponse> createOrLoginPro(params);
  Future<NetworkResponse> loginUserByPhone(params);
  Future<NetworkResponse> loginUserByEmail(params);
  Future<NetworkResponse> createOrLoginUser(params);
  Future<NetworkResponse> createNewUser(params);
  Future<NetworkResponse> subRegisterUser(params);
  Future<NetworkResponse> getUserInfo();
  Future<NetworkResponse> getProInfo();
  Future<NetworkResponse> updatePro(params);
  Future<NetworkResponse> updateProFromSA(params);
  Future<NetworkResponse> updateUser(params);
  Future<NetworkResponse> updateUserFromSA(params);
  Future<NetworkResponse> updateNewUserPasswordByFirebase(params);
  Future<NetworkResponse> addNotificationToken(params);
  Future<NetworkResponse> setThumbnailForUser(bytes, filePath);
  Future<NetworkResponse> setThumbnailForPro(bytes, filePath);
  Future<NetworkResponse> updateProPwd(String oldPassword, String newPassword);
  Future<NetworkResponse> updateUserPwd(String oldPassword, String newPassword);
  Future<NetworkResponse> logoutPro(params);
  Future<NetworkResponse> logoutUser(params);
  Future<NetworkResponse> checkUpdateEmailFromUser(params);
  Future<NetworkResponse> confirmUpdateUserEmailCode(email, code, phone);
  Future<NetworkResponse> updateUserEmail(token);
  Future<NetworkResponse> checkUpdateEmailFromPro(params);
  Future<NetworkResponse> confirmUpdateProEmailCode(email, code);
  Future<NetworkResponse> updateProEmail(token);
  Future<NetworkResponse> loginPro(params);
  Future<NetworkResponse> loginUserByPhoneAndFirebase(params);
  Future<NetworkResponse> loginProByPhoneAndFirebase(params);
  Future<NetworkResponse> loginProCrmByQrCode(params);
  Future<NetworkResponse> checkNewProEmail(params);
  Future<NetworkResponse> checkEmailPro(params);
  Future<NetworkResponse> checkIfEmailExist(params);
  Future<NetworkResponse> checkNewEmailUserEmailConfirm(params);
  Future<NetworkResponse> confirmNewProCode(params);
  Future<NetworkResponse> createNewPro(params);
  Future<NetworkResponse> getCategoriesList();
  Future<NetworkResponse> checkExistEmailFromPro(params);
  Future<NetworkResponse> resetProPassword(params);
  Future<NetworkResponse> confirmResetProPasswordCode(params);
  Future<NetworkResponse> updateNewProPasswordByToken(params);
  Future<NetworkResponse> getProInfoByUniqueId(uniqueId);
  Future<NetworkResponse> getUserInfoByUniqueId(uniqueId);
  Future<NetworkResponse> getAssetsForProFromUniversalDashboard(proUniqueId);
  Future<NetworkResponse> getIndustriesList();
  Future<NetworkResponse> checkLoginProByEmailOTP(params);
  Future<NetworkResponse> loginProByEmailOTPConfirm(params);

  ///Google place
  Future<NetworkResponse> googlePlaceAutoComplete(String keyword,
      {String? countryCode, List<String>? types});
  Future<NetworkResponse> googlePlaceSearchById(String placeId);
  Future<NetworkResponse> googlePlaceSeachPlaceByText(String keyword,
      [String? types]);
  Future<NetworkResponse> googlePlaceSeachPlaceDetailById(placeId);
  Future<NetworkResponse> googleGeocode(latlng);

  ///Google place pass our sever
  Future<NetworkResponse> arckipelgooglePlaceSearch(params);
  Future<NetworkResponse> arckipelgooglePlaceSeachPlaceDetailById(params);

  /// Core
  Future<NetworkResponse> getDateFormatList();
  Future<NetworkResponse> getTimeFormatList();
  Future<NetworkResponse> getPhoneAvailable();
  Future<NetworkResponse> getCountryAvailable();
  Future<NetworkResponse> getLanguageAvailable();
  Future<NetworkResponse> getCurrencies();
  Future<NetworkResponse> getLanguageForSpeakAvailable();
  Future<NetworkResponse> getAllowedFeaturesForOowooApp();
  Future<NetworkResponse> getTncOowooApp();
  Future<NetworkResponse> getTncOowooSeller();
  Future<NetworkResponse> testSendNotificationToUser(params);
  Future<NetworkResponse> testSendNotificationToPro(params);
  Future<NetworkResponse> notifVideoCallUserFromPro(params);
  Future<NetworkResponse> notifVideoCallProFromUser(params);
  Future<NetworkResponse> v2_getDashboardConfigFromPro();

  ///Contacts
  Future<NetworkResponse> getContactsList(params);
  Future<NetworkResponse> addUserInContactsList(params);
  Future<NetworkResponse> addUserOrProToContactListByFirebaseId(params);
  Future<NetworkResponse> updateCommentForContact(params);
  Future<NetworkResponse> deleteContact(params);
  Future<NetworkResponse> getExistingUserByPhone(params);
  Future<NetworkResponse> checkAndAddNewContact(params);

  ///My products
  Future<NetworkResponse> getProductCategories();
  Future<NetworkResponse> getStatusList();
  Future<NetworkResponse> getProductsFromPro(params);
  Future<NetworkResponse> getProductOfProFromSA(params);
  Future<NetworkResponse> getProductOfUserFromSA(params);
  Future<NetworkResponse> updateTerminalFromPro(params);
  Future<NetworkResponse> v2_sendPropertyToTerminal(params);
  Future<NetworkResponse> v2_removePropertyFromTerminal(params);
  Future<NetworkResponse> updateProduct(params);
  Future<NetworkResponse> getTerminalsFromPro(terminalType);
  Future<NetworkResponse> linkTerminalToProV2(params);
  Future<NetworkResponse> getAllTerminalFromAdmin(params);
  Future<NetworkResponse> v2_getCurrentTerminalsOfPlaylistFromPro(params);

  ///PublicEvents
  Future<NetworkResponse> getAllPublicEventsAroundMe(params);
  Future<NetworkResponse> getPublicEventsListFromUser(params);
  Future<NetworkResponse> getPublicEventsCategories(languageCode);
  Future<NetworkResponse> getFavoritePublicEventsCategoriesFromUser(
      languageCode);
  Future<NetworkResponse> getSuggestionEventsFromUser(params);
  Future<NetworkResponse> getAllPublicEventsFromSearch(params);
  Future<NetworkResponse> getLikedPublicEventsFromUser();
  Future<NetworkResponse> addUserLikeToPublicEvent(publicEventId);
  Future<NetworkResponse> setFavoriteCatForUser(catId);
  Future<NetworkResponse> removeFavoriteCatForUser(catId);
  Future<NetworkResponse> addSeenSuggestionEventFromUser(
      publicEventId, utcModifier);
  Future<NetworkResponse> bookFreeTicketForPublicEvents(proUniqueId);
  Future<NetworkResponse> getTicketListFromPublicEvent(publicEventId);

  ///Payments
  Future<NetworkResponse> getCustomerCardsStripe(page, pageSize);
  Future<NetworkResponse> createCustomerCardStripe(params);
  Future<NetworkResponse> deleteCustomerCardStripe(cardId);
  Future<NetworkResponse> setCustomerCardDefaultStripe(cardId);
  Future<NetworkResponse> getWalletInfo();
  Future<NetworkResponse> createPurchaseByCardOnFileStripe(params);
  Future<NetworkResponse> createPurchaseByTokenStripe(params);
  Future<NetworkResponse> createPurchaseByPaymentMethodStripe(params);
  // Future<NetworkResponse> getPurchaseStripe(params);
  // Future<NetworkResponse> getPurchasesStripe(params);

  //Locations
  Future<NetworkResponse> addLocationForUser(params);
  Future<NetworkResponse> getLocationFromUser(params);
  Future<NetworkResponse> removeLocationForUser(params);
  Future<NetworkResponse> setLocationDefault(params);
  Future<NetworkResponse> updateLocationForUser(params);

  //Filter events/services
  Future<NetworkResponse> getMaincatList(params);
  Future<NetworkResponse> getCategoriesFromEventsWebsite(params);
  Future<NetworkResponse> getResultsByCatFromEventsWebsite(params);
  Future<NetworkResponse> getAllEventsFromEventsWebsite(params);
  Future<NetworkResponse> getSubcatList(params);
  Future<NetworkResponse> getSpecList(params);
  Future<NetworkResponse> getHashtagsList(params);
  Future<NetworkResponse> getResultsFromFilters(params);
  Future<NetworkResponse> getResultsFromSearch(params);

  ///Sellers
  Future<NetworkResponse> becomeSeller(confirmed);
  Future<NetworkResponse> updateImageForBecomeSeller(fileType, file);
  Future<NetworkResponse> quitSellerProgram(temp);
  Future<NetworkResponse> recoverySellerProgram();
  Future<NetworkResponse> getMissionsFromSeller(params);
  Future<NetworkResponse> getMissionTypes(params);
  Future<NetworkResponse> takeMissionFromSeller(missionId);
  Future<NetworkResponse> getNumberOfSalesFromSellers(params);
  Future<NetworkResponse> setBankAccountFromUser(params);
  Future<NetworkResponse> getAccountTypes();
  Future<NetworkResponse> getBankInfosFromSeller();
  Future<NetworkResponse> updateBankInfosFromSeller(params);

  ///Other
  // https://byabbe.se/on-this-day/3/18/events.json
  // https://byabbe.se/on-this-day/3/18/births.json
  // https://byabbe.se/on-this-day/3/18/deaths.json
  Future<NetworkResponse> eventsOnThisDay(date);
  Future<NetworkResponse> birthsOnThisDay(date);
  Future<NetworkResponse> deathsOnThisDay(date);
  Future<NetworkResponse> pexelsSearch(params);
  //Weather
  Future<NetworkResponse> weatherForecast(params);
  Future<NetworkResponse> weatherHistory(params);

  //Movies
  Future<NetworkResponse> themoviedbSearchMovie(params);
  Future<NetworkResponse> themoviedbSearchPerson(params);
  Future<NetworkResponse> themoviedbSearchKeyword(params);
  Future<NetworkResponse> themoviedbSearchMulti(params);
  Future<NetworkResponse> themoviedbMovieDetail(id, params);
  Future<NetworkResponse> themoviedbMovieDetailCredits(id, params);
  Future<NetworkResponse> themoviedbMovieDetailImages(id, params);
  Future<NetworkResponse> themoviedbMovieDetailVideos(id, params);
  Future<NetworkResponse> themoviedbMovieDetailSimilar(id, params);
  Future<NetworkResponse> themoviedbMovieReview(id, params);
  Future<NetworkResponse> themoviedbTrending(media_type, time_window, params);
  Future<NetworkResponse> themoviedbDiscoverMovie(params);
  Future<NetworkResponse> themoviedbGenres(params);
  Future<NetworkResponse> themoviedbPersonDetail(id, params);
  Future<NetworkResponse> themoviedbPersonDetailImages(id, params);
  Future<NetworkResponse> themoviedbPersonCredits(id, params);
  Future<NetworkResponse> themoviedbConfigLanguage(params);
  // Future<NetworkResponse> themoviedb(params);
  Future<NetworkResponse> createMovieCollection(params);
  Future<NetworkResponse> updateMovieCollection(params);
  Future<NetworkResponse> getMyMovieCollections(params);
  Future<NetworkResponse> addMovieInArckipelDb(params);
  Future<NetworkResponse> addMovieBookmarksToCollection(params);
  Future<NetworkResponse> removeMovieFromCollection(params);
  Future<NetworkResponse> getMyBookmarks(params);
  Future<NetworkResponse> updateMyMovieInfos(params);

  //Bars restaurants
  Future<NetworkResponse> getOoBRPlacesAroundMe(params);
  Future<NetworkResponse> getOoBRPlacesByFilterValues(params);
  Future<NetworkResponse> getFavoriteOobrPlaces();
  Future<NetworkResponse> getOoBRPlaceInfoById(params);
  Future<NetworkResponse> updateFilterValueForOobr(params);
  Future<NetworkResponse> getPromotedVideosForBar(oobrPlaceId);
  Future<NetworkResponse> getPromotedVideosForOobrPlaces(lat, lng);
  Future<NetworkResponse> getOoBRCategories(languageCode);
  Future<NetworkResponse> getOoBRFilters(languageCode);
  Future<NetworkResponse> checkBarGooglePlaceIdByContributor(googlePlaceId);
  Future<NetworkResponse> createNewOobrPlaceByContributor(params);
  Future<NetworkResponse> addOobrPlaceToFavorites(oobrPlaceId);
  Future<NetworkResponse> getOobrPlaceSchedules(oobrPlaceId);
  Future<NetworkResponse> getOobrPlaceMenuList(oobrPlaceId, languageCode);
  Future<NetworkResponse> getOobrPlaceMenuContent(menuId, languageCode);
  Future<NetworkResponse> getOptionsForItem(itemId, languageCode);
  Future<NetworkResponse> getAllergensForItem(itemId, languageCode);
  Future<NetworkResponse> createOrderForOobrPlace(params);
  Future<NetworkResponse> getAnythingFromQr(params);
  Future<NetworkResponse> getDetailOobrInvitations(oobrEventId);
  Future<NetworkResponse> inviteContactsToOobrPlace(params);
  Future<NetworkResponse> answerOobrInvitation(params);

  ///Emergency
  Future<NetworkResponse> getEmergencyInfos(params);
  Future<NetworkResponse> sendEmergencyRequest(params);

  ///PersonalEvents
  Future<NetworkResponse> createSharedPcEvent(params);
  Future<NetworkResponse> setThumbnailForPcEvent(path, pcEventId);
  Future<NetworkResponse> shareCalendarToUsers(params);
  Future<NetworkResponse> getPcEventFromUser(pcEventId);
  Future<NetworkResponse> getPcEventFromPro(pcEventId);

  ///Home
  Future<NetworkResponse> getHomesAroundMe(params);
  Future<NetworkResponse> getPromotedVideosForOoh(lat, lng);

  ///Whatnext
  Future<NetworkResponse> whatsNext(params);
  Future<NetworkResponse> getReminderTypes();
//Agora
  Future<NetworkResponse> generateToken(channelName, expiredTime);
//Homelido
  Future<NetworkResponse> getHomelidoPropertyCategories(languageCode);
  Future<NetworkResponse> getPropertiesFromPro(languageCode);
  Future<NetworkResponse> v2_getCurrentPropertiesOfTerminal(params);
  Future<NetworkResponse> createHomlidoMeeting(params);
  Future<NetworkResponse> getHomelidoMeetingDetails(params);
  Future<NetworkResponse> answerToHomelidoVisitRequest(params);
//Tracking position
  Future<NetworkResponse> getTrackingInfosForMeeting(params);
  Future<NetworkResponse> addUserOrProToTrackingPeople(params);
  Future<NetworkResponse> updateTrackingInfosForMeeting(params);
  Future<NetworkResponse> getLearnMoreTrackingVideo();
//Move
  Future<NetworkResponse> getOowooMoveProperties(params);
  Future<NetworkResponse> getOowooVideoByTypeId(typeId);
//Relax
  Future<NetworkResponse> getCalmCategories();
  Future<NetworkResponse> getCalmByCat(params);
  Future<NetworkResponse> subscribeToCalmId(calmId);
  Future<NetworkResponse> getSubscribersForCalmId(params);
//Agora
  Future<NetworkResponse> getReviewsFromPro(proId);
//Appointment
  Future<NetworkResponse> getAllEventsFromUser();
  Future<NetworkResponse> getEventInfoFromUser(eventUniqueId);
  Future<NetworkResponse> getQueueInfoFromUser(ticketUniqueId);
  Future<NetworkResponse> cancelTicketByUser(ticketUniqueId, status, comment);
  Future<NetworkResponse> confirmTicketByUser(ticketUniqueId, status, comment);
  Future<NetworkResponse> ticketUserCallBack(ticketUniqueId, duration);
  Future<NetworkResponse> deleteEventsFromUser(ticketUniqueId);
  Future<NetworkResponse> getUserInfoByFirebaseId(firebaseId);
  Future<NetworkResponse> getProInfoByFirebaseId(firebaseId);
//Others
  Future<NetworkResponse> getVideoConfigFromPlayerVimeo(vimeoId);
  Future<NetworkResponse> getFavouriteForUser();
  Future<NetworkResponse> removeFromFavourite(proId);
  Future<NetworkResponse> addToFavourite(proId);
//Digicodes
  Future<NetworkResponse> getCodesFromPro(params);
  Future<NetworkResponse> createCode(params);
  Future<NetworkResponse> updateLiveCode(params);
  Future<NetworkResponse> shareCodeDigicode(params);
  Future<NetworkResponse> deleteLiveCode(params);
  Future<NetworkResponse> getDigicodesFromPro(params);
  Future<NetworkResponse> getPlacesFromPro(params);
  Future<NetworkResponse> getPlaceCatByLang(params);
  Future<NetworkResponse> createPlace(params);
  Future<NetworkResponse> unlockDigicode(params);
  Future<NetworkResponse> getDigicodesLogs(params);
  Future<NetworkResponse> deleteCodeFromLog(params);
  Future<NetworkResponse> checkDigicodeOnline(digicodeId);
  Future<NetworkResponse> getDigicodeById(id);
  Future<NetworkResponse> checkDigicodeBySerialAndToken(
      productSerial, authcode);
  Future<NetworkResponse> linkDigicodeToPro(params);
  Future<NetworkResponse> linkDigicodeToProV2(params);
//Pro zone
  Future<NetworkResponse> setMainLanguageForPro(proLanguageCode);
  Future<NetworkResponse> setLanguagesForPro(proLanguageCode);
// Appointment
  Future<NetworkResponse> getAllEventsFromPro();
  Future<NetworkResponse> getAllServicesOfProFromPro(params);
  Future<NetworkResponse> updateDelay(params);
  Future<NetworkResponse> cancelTicketByPro(ticketUniqueId);
  Future<NetworkResponse> confirmTicketByPro(ticketUniqueId, status, comment);
  Future<NetworkResponse> declareUserAsAbsentFromPro(ticketUniqueId);
  Future<NetworkResponse> ticketUserNotResponse(ticketUniqueId);
  Future<NetworkResponse> startTicket(ticketUniqueId);
  Future<NetworkResponse> stopTicket(ticketUniqueId);
  Future<NetworkResponse> canceledByProAfterCallBack(ticketUniqueId);
  Future<NetworkResponse> callNextTicket(serviceId);
  Future<NetworkResponse> getEventInfoFromPro(eventUniqueId);
  Future<NetworkResponse> getListTimeFramesByServiceForDay(
      dateToday, serviceId);
  Future<NetworkResponse> getServiceAvailabilityForMonth(params);
  Future<NetworkResponse> createTicketByPro(params);
  Future<NetworkResponse> deleteEventsFromPro(ticketUniqueId);
  Future<NetworkResponse> createTicketByUser(params);
  Future<NetworkResponse> getAllServicesOfProFromUser(params);
  Future<NetworkResponse> getAllServicesAroundMe(params);
//Playlist
  Future<NetworkResponse> v2_getPlaylistFromPro(params);
  Future<NetworkResponse> v2_createPlaylistFromPro(params);
  Future<NetworkResponse> v2_deletePlaylistFromPro(params);
  Future<NetworkResponse> v2_getItemContentFromPlaylist(params);
  Future<NetworkResponse> v2_addItemToPlaylist(params);
  Future<NetworkResponse> v2_removeItemFromPlaylist(params);
  Future<NetworkResponse> v2_getPlaylistsFromTerminal(params);
  Future<NetworkResponse> v2_linkPlaylistToTerminalForPro(params);
  Future<NetworkResponse> v2_addScheduleForPlaylist(params);
  Future<NetworkResponse> v2_updateScheduleForPlaylist(params);
  Future<NetworkResponse> v2_removeScheduleForPlaylist(params);
  Future<NetworkResponse> v2_updateOrderItemsFromPlaylist(params);
//Security
  Future<NetworkResponse> getLoginSessions(params);
  Future<NetworkResponse> getLoginSessionsById(params);
  Future<NetworkResponse> revokeLoginSession(params);
  Future<NetworkResponse> allowPendingLoginOnPlatformByQrCode(params);
  Future<NetworkResponse> allowPendingLoginOnPlatformById(params);

  ///History pmb
  Future<NetworkResponse> getHistoryFromUser();

  ///pmb
  Future<NetworkResponse> getBgVideo(countryCode);
  Future<NetworkResponse> getPmbDevicesAroundMe(params);
  Future<NetworkResponse> scanDeviceQr(params);
  Future<NetworkResponse> activatePourDevice(deviceId);
  Future<NetworkResponse> ipAPI();
  Future<NetworkResponse> getCurrencyAvailableForToken(tokenType);
  Future<NetworkResponse> getCurrentTokenValue(tokenType, {currency = 'EUR'});
  Future<NetworkResponse> getPlatformsList(params);
  Future<NetworkResponse> getPlatformsListDoubleAuth(params);
  Future<NetworkResponse> activateDoubleAuthForPlatform(params);
  Future<NetworkResponse> createNonExistingRandomCode(params);
  Future<NetworkResponse> v2_getProblemTypesList(params);
  Future<NetworkResponse> getFaqForProblemType(params);
  Future<NetworkResponse> v2_getMyTicketsFromCustomer(params);
  Future<NetworkResponse> v2_postTicketByCustomer(params);
  Future<NetworkResponse> getFaqGroupsFromPlatformId(params);
  Future<NetworkResponse> getProblemTypesForGroupId(params);
  Future<NetworkResponse> clickOnFaq(params);
  Future<NetworkResponse> v2_getMyTicketsFromAgent(ticketStatusId);
  Future<NetworkResponse> v2_answerToTicketFromAgent(params);
  Future<NetworkResponse> v2_answerToTicketFromCustomer(params);
  Future<NetworkResponse> getAnswersOfTicket(ticketId);
  Future<NetworkResponse> v2_getAgentList();
  Future<NetworkResponse> v2_assignTicketToAgents(params);
  Future<NetworkResponse> getLinksListFromMainLink(params);
  Future<NetworkResponse> createFirebaseDynamicLink(params);
  Future<NetworkResponse> loginTerminal(params);
  Future<NetworkResponse> getVideoPlaylistsFromTerminal(params);
  Future<NetworkResponse> getServicesListFromTerminal();
  Future<NetworkResponse> getNextTicketAvailableForQueueFromTerminal(id);
  Future<NetworkResponse> cancelNextTicketAvailableForQueueFromTerminal(id);
  Future<NetworkResponse> getPropertiesDetailsByList(params);
  Future<NetworkResponse> getListOfRoles(params);
  Future<NetworkResponse> setProRole(params);
  Future<NetworkResponse> getThumbnailUrlsForCat(params);
  Future<NetworkResponse> getThumbnailCat(params);
  Future<NetworkResponse> addThumbnailUrlForCat(bytes, filePath, label, catId);
  Future<NetworkResponse> createThumbnailCat(params);
  Future<NetworkResponse> updateThumbnailUrlForCat(bytes, filePath, label, id);
  Future<NetworkResponse> deleteThumbnailUrlForCat(params);
  Future<NetworkResponse> getListOfProsFromAdmin(params);
  Future<NetworkResponse> getListOfUsersFromAdmin(params);
  Future<NetworkResponse> v2GetProductCategories(params);
  Future<NetworkResponse> v2getProductRefByCatId(params);
  Future<NetworkResponse> getProInfosFromSA(params);
  Future<NetworkResponse> getUserInfosFromSA(params);
  Future<NetworkResponse> setKisblePublicThumbnailForPro(bytes, path, proId);
  Future<NetworkResponse> setThumbnailForProFromSA(bytes, path, proId);
  Future<NetworkResponse> setThumbnailForUserFromSA(bytes, path, proId);

  Future<NetworkResponse> getCrmStatusList(params);
  Future<NetworkResponse> getListOfLeadsFromPro(params);
  Future<NetworkResponse> getCrmIntouchList(params);
  Future<NetworkResponse> getCrmLeadHistory(params);
  Future<NetworkResponse> createCrmProjectFromPro(params);
  Future<NetworkResponse> getListCrmProjectsFromPro(params);
  Future<NetworkResponse> createCrmLead(params);
  Future<NetworkResponse> updateCrmLead(params);
  Future<NetworkResponse> setThumbnailForCrmLead(bytes, path, uuid);
  Future<NetworkResponse> deleteCrmLead(params);
  Future<NetworkResponse> addCrmLeadsToProject(params);
  Future<NetworkResponse> removeCrmLeadsToProject(params);
  Future<NetworkResponse> getCrmLeadDetails(params);
  Future<NetworkResponse> createInTouchHistory(params);
  Future<NetworkResponse> addCrmProjectMember(params);
  Future<NetworkResponse> removeCrmProjectMember(params);
  Future<NetworkResponse> getCrmProjectMemberList(params);

  Future<NetworkResponse> marketPlaceGetProductRefByCat(params);
  Future<NetworkResponse> createAsOrder(params);
  Future<NetworkResponse> getPaymentMethodList(params);
  Future<NetworkResponse> getPaymentStatusList(params);
  Future<NetworkResponse> getOrdersFromProOrUser(params);
  Future<NetworkResponse> getOrdersFromAdmin(params);
  Future<NetworkResponse> updateOrderDetailsByAdmin(params);
  Future<NetworkResponse> payOrder(params);

  Future<NetworkResponse> getBillingInfosFromProOrUser(params);
  Future<NetworkResponse> getBillingInfosFromPro(params);
  Future<NetworkResponse> updateBillingInfosFromProOrUser(params);
  Future<NetworkResponse> deleteBillingInfosFromProOrUser(params);
  Future<NetworkResponse> addBillingInfosFromProOrUser(params);
  Future<NetworkResponse> setDefaultBillingInfos(params);

  Future<NetworkResponse> getHomePurposeTypesList(params);
  Future<NetworkResponse> getCountriesAvailableForHomes(params);
  Future<NetworkResponse> getHomeDetails(params);
  Future<NetworkResponse> getHomeCatList(params);
  Future<NetworkResponse> getCurrentFiltersAvailable(params);
  Future<NetworkResponse> getCitiesListByPurposeId(params);
  Future<NetworkResponse> getHomesListByFilters(params);
  Future<NetworkResponse> setHomeBookmark(params);
  Future<NetworkResponse> createOohHome(params);
  Future<NetworkResponse> updateOohHome(params);
  Future<NetworkResponse> setMainPicForHome(bytes, path, homeId);
  Future<NetworkResponse> setGalleryPicForHome(bytes, path, homeId);
  Future<NetworkResponse> getHomeCitiesList(params);
  Future<NetworkResponse> getMediaForOoh(params);
  Future<NetworkResponse> getHomesListForUserOrPro(params);
  Future<NetworkResponse> getHomeBookmarkList(params);
  Future<NetworkResponse> getListOfAgencies(params);
  Future<NetworkResponse> getSubscriptionState(params);
  Future<NetworkResponse> getCurrencyOfCountry(params);
  Future<NetworkResponse> removeGalleryPicForHome(params);
  // Future<NetworkResponse> _____(params);
  // Future<NetworkResponse> _____(params);
  // Future<NetworkResponse> _____(params);
  // Future<NetworkResponse> _____(params);
}
