import 'dart:io';

import 'package:dio/dio.dart';
import 'package:_private_core/_private_core.dart';
import '../model/google_place/autocomplete_prediction.dart';
import '../model/google_place/details_response.dart';
import 'app_endpoint.dart';
import '../resources.dart';
import 'client_web.dart';

class AppApiImp extends AppApi {
  @override
  Future<NetworkResponse> refreshUserToken(refreshToken) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response =
          await AppClientsWeb(requiredToken: true, token: refreshToken)
              .post(AppEndpoint.refreshUserToken());
      return NetworkResponse.fromResponse(response,
          converter: (json) => Token.fromJson(json), prefix: '');
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> refreshProToken(refreshToken) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response =
          await AppClientsWeb(requiredToken: true, token: refreshToken)
              .post(AppEndpoint.refreshProToken());
      return NetworkResponse.fromResponse(response,
          converter: (json) => Token.fromJson(json), prefix: '');
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> checkNewPhoneFromUser(phone) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response =
          await AppClientsWeb(requiredToken: false, enableErrorHandler: false)
              .get(AppEndpoint.checkNewPhoneFromUser(),
                  queryParameters: {'phone': phone});
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> checkNewPhoneFromPro(phone) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response =
          await AppClientsWeb(requiredToken: false, enableErrorHandler: false)
              .get(AppEndpoint.checkNewPhoneFromPro(),
                  queryParameters: {'phone': phone});
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> checkExistPhoneFromUser(phone) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false).get(
          AppEndpoint.checkExistPhoneFromUser(),
          queryParameters: {'phone': phone});
      return NetworkResponse.fromResponse(response,
          converter: (json) => UserModel.fromJson(json), prefix: '');
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> addNotificationToken(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.addNotificationToken(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> createOrLoginPro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .post(AppEndpoint.createOrLoginPro(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => Token.fromJson(json), prefix: '');
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> updateNewUserPasswordByFirebase(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .post(AppEndpoint.updateNewUserPasswordByFirebase(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> loginUserByPhone(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
        requiredToken: false,
        enableErrorHandler: false,
      ).post(
        AppEndpoint.loginUserByPhone(),
        data: params,
      );
      return NetworkResponse.fromResponse(response,
          converter: (json) => Token.fromJson(json), prefix: '');
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> loginUserByPhoneAndFirebase(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
        requiredToken: false,
        enableErrorHandler: false,
      ).post(
        AppEndpoint.loginUserByPhoneAndFirebase(),
        data: params,
      );
      return NetworkResponse.fromResponse(response,
          converter: (json) => Token.fromJson(json), prefix: '');
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> loginUserByEmail(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .post(AppEndpoint.loginUserByEmail(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => Token.fromJson(json), prefix: '');
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> createOrLoginUser(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .post(AppEndpoint.createOrLoginUser(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => Token.fromJson(json), prefix: '');
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> createNewUser(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .post(AppEndpoint.createNewUser(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => Token.fromJson(json), prefix: '');
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> subRegisterUser(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .post(AppEndpoint.subRegisterUser(), data: params);
      return NetworkResponse.fromResponse(response);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getUserInfo() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .get(AppEndpoint.getUserInfo());
      return NetworkResponse.fromResponse(response,
          converter: (json) => UserModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getProInfo() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .get(AppEndpoint.getProInfo());
      return NetworkResponse.fromResponse(response,
          converter: (json) => ProInfo.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> updateUser(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .put(AppEndpoint.updateUser(), data: params);
      return NetworkResponse.fromResponse(response,
          value: UpdateInfoResult(status: response.statusCode == 200));
    } on DioError catch (e) {
      if (e.response?.data != null && e.response!.data['error'] is String) {
        return NetworkResponse.fromResponse(e.response!,
            value: UpdateInfoResult(
                status: false, msg: e.response!.data['error']));
      }
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> updatePro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .put(AppEndpoint.updatePro(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> updateProFromSA(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .put(AppEndpoint.updateProFromSA(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> updateUserFromSA(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .put(AppEndpoint.updateUserFromSA(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> logoutPro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .post(AppEndpoint.logoutPro(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> logoutUser(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .post(AppEndpoint.logoutUser(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> setThumbnailForUser(bytes, filePath) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      String fileName = filePath.split('/').last;
      FormData formData = FormData.fromMap({
        "fileName": MultipartFile.fromBytes(bytes, filename: fileName),
      });
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .post(AppEndpoint.setThumbnailForUser(), data: formData);
      return NetworkResponse.fromResponse(response,
          converter: (json) => json['fileName']);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> setThumbnailForPro(bytes, filePath) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      String fileName = filePath.split('/').last;
      FormData formData = FormData.fromMap({
        "fileName": MultipartFile.fromBytes(bytes, filename: fileName),
      });
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .post(AppEndpoint.setThumbnailForPro(), data: formData);
      return NetworkResponse.fromResponse(response,
          converter: (json) => json['fileName']);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> updateProPwd(
      String oldPassword, String newPassword) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .put(AppEndpoint.updateProPwd(),
              data: {'oldPassword': oldPassword, 'newPassword': newPassword});
      return NetworkResponse.fromResponse(response,
          value: UpdateInfoResult(status: response.statusCode == 200));
    } on DioError catch (e) {
      if (e.response?.data != null && e.response!.data['error'] is String) {
        return NetworkResponse.fromResponse(e.response!,
            value: UpdateInfoResult(
                status: false, msg: e.response!.data['error']));
      }
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> updateUserPwd(
      String oldPassword, String newPassword) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .put(AppEndpoint.updateUserPwd(),
              data: {'oldPassword': oldPassword, 'newPassword': newPassword});
      return NetworkResponse.fromResponse(response,
          value: UpdateInfoResult(status: response.statusCode == 200));
    } on DioError catch (e) {
      if (e.response?.data != null && e.response!.data['error'] is String) {
        return NetworkResponse.fromResponse(e.response!,
            value: UpdateInfoResult(
                status: false, msg: e.response!.data['error']));
      }
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> checkUpdateEmailFromUser(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .post(AppEndpoint.checkUpdateEmailFromUser(), data: params);
      return NetworkResponse.fromResponse(response,
          value: UpdateInfoResult(status: response.statusCode == 200));
    } on DioError catch (e) {
      if (e.response?.data != null && e.response!.data['error'] is String) {
        return NetworkResponse.fromResponse(e.response!,
            value: UpdateInfoResult(
                status: false, msg: e.response!.data['error']));
      }
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> confirmUpdateUserEmailCode(email, code, phone) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .post(AppEndpoint.confirmUpdateUserEmailCode(),
              data: {'email': email, 'code': code, 'phone': phone});
      return NetworkResponse.fromResponse(response,
          converter: (json) => ConfirmEmailCodeResponse.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> updateUserEmail(_token) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .put(AppEndpoint.updateUserEmail(), data: {'token': _token});
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> checkUpdateEmailFromPro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .post(AppEndpoint.checkUpdateEmailFromPro(), data: params);
      return NetworkResponse.fromResponse(response,
          value: UpdateInfoResult(status: response.statusCode == 200));
    } on DioError catch (e) {
      if (e.response?.data != null && e.response!.data['error'] is String) {
        return NetworkResponse.fromResponse(e.response!,
            value: UpdateInfoResult(
                status: false, msg: e.response!.data['error']));
      }
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> confirmUpdateProEmailCode(email, code) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .post(AppEndpoint.confirmUpdateProEmailCode(),
              data: {'email': email, 'code': code});
      return NetworkResponse.fromResponse(response,
          converter: (json) => ConfirmEmailCodeResponse.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> updateProEmail(_token) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .put(AppEndpoint.updateProEmail(), data: {'token': _token});
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> checkExistEmailFromPro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .get(AppEndpoint.checkExistEmailFromPro(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> checkNewProEmail(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .post(AppEndpoint.checkNewProEmail(), data: params);
      return NetworkResponse.fromResponse(response,
          value: CheckNewEmailProResult(statusCode: response.statusCode));
    } on DioError catch (e) {
      if (e.response != null &&
          e.response!.statusCode == 400 &&
          e.response!.data != null) {
        return NetworkResponse.fromResponse(e.response!,
            value: CheckNewEmailProResult(
              statusCode: e.response!.statusCode,
              msg: e.response!.data['error'],
              thumbnail: e.response!.data['thumbnail'],
              roleId: e.response!.data['roleId'],
              displayName: e.response!.data['displayName'],
            ));
      }
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> checkIfEmailExist(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .post(AppEndpoint.checkIfEmailExist(), data: params);
      return NetworkResponse.fromResponse(response,
          value: CheckNewEmailProResult(statusCode: response.statusCode));
    } on DioError catch (e) {
      if (e.response != null &&
          e.response!.statusCode == 400 &&
          e.response!.data != null) {
        return NetworkResponse.fromResponse(e.response!,
            value: CheckNewEmailProResult(
              statusCode: e.response!.statusCode,
              msg: e.response!.data['error'],
              thumbnail: e.response!.data['thumbnail'],
              roleId: e.response!.data['roleId'],
              displayName: e.response!.data['displayName'],
            ));
      }
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> checkNewEmailUserEmailConfirm(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .post(AppEndpoint.checkNewEmailUserEmailConfirm(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => ConfirmOtp.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> checkEmailPro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .post(AppEndpoint.checkEmailPro(), data: params);
      return NetworkResponse.fromResponse(response,
          value: CheckNewEmailProResult(statusCode: response.statusCode));
    } on DioError catch (e) {
      if (e.response != null &&
          e.response!.statusCode == 400 &&
          e.response!.data != null) {
        return NetworkResponse.fromResponse(e.response!,
            value: CheckNewEmailProResult(
              statusCode: e.response!.statusCode,
              msg: e.response!.data['error'],
              thumbnail: e.response!.data['thumbnail'],
              roleId: e.response!.data['roleId'],
              displayName: e.response!.data['displayName'],
            ));
      }
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> confirmNewProCode(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .post(AppEndpoint.confirmNewProCode(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => ConfirmOtp.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> confirmResetProPasswordCode(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .post(AppEndpoint.confirmResetProPasswordCode(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => ConfirmOtp.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> createNewPro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .post(AppEndpoint.createNewPro(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => Token.fromJson(json), prefix: '');
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getCategoriesList() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false).get(
          AppEndpoint.getCategoriesList(),
          queryParameters: {'catLanguageCode': null});
      return NetworkResponse.fromResponse(
        response,
        converter: (json) =>
            (json['maincats'] as List).map((e) => MainCat.fromJson(e)).toList(),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> loginPro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .post(AppEndpoint.loginPro(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => Token.fromJson(json), prefix: '');
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> loginProByPhoneAndFirebase(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .post(AppEndpoint.loginProByPhoneAndFirebase(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => Token.fromJson(json), prefix: '');
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> loginProCrmByQrCode(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .post(AppEndpoint.loginProCrmByQrCode(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => Token.fromJson(json), prefix: '');
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> resetProPassword(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .post(AppEndpoint.resetProPassword(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> updateNewProPasswordByToken(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .post(AppEndpoint.updateNewProPasswordByToken(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getProInfoByUniqueId(uniqueId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false).get(
          AppEndpoint.getProInfoByUniqueId(),
          queryParameters: {'uniqueId': uniqueId});
      return NetworkResponse.fromResponse(response,
          converter: (json) => ProInfo.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getUserInfoByUniqueId(uniqueId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false).get(
          AppEndpoint.getUserInfoByUniqueId(),
          queryParameters: {'uniqueId': uniqueId});
      return NetworkResponse.fromResponse(response,
          converter: (json) => UserModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> checkLoginProByEmailOTP(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .post(AppEndpoint.checkLoginProByEmailOTP(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> loginProByEmailOTPConfirm(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .post(AppEndpoint.loginProByEmailOTPConfirm(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => Token.fromJson(json), prefix: '');
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getAssetsForProFromUniversalDashboard(
      proUniqueId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false).get(
          AppEndpoint.getAssetsForProFromUniversalDashboard(),
          queryParameters: {'proUniqueId': proUniqueId});
      return NetworkResponse.fromResponse(response,
          converter: (json) => OrgProInfo.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse<List<Country>>> getPhoneAvailable() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false).get(
          AppEndpoint.getPhoneAvailable(),
          queryParameters: {'phoneAvailable': 1});
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<Country>((i) => Country.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse<List<DateFormatModel>>> getDateFormatList() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .get(AppEndpoint.getDateFormatList());
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<DateFormatModel>((i) => DateFormatModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse<List<TimeFormatModel>>> getTimeFormatList() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .get(AppEndpoint.getTimeFormatList());
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<TimeFormatModel>((i) => TimeFormatModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse<List<Country>>> getCountryAvailable() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false).get(
          AppEndpoint.getCountryAvailable(),
          queryParameters: {'available': 1});
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<Country>((i) => Country.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse<List<IndustryModel>>> getIndustriesList() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false).get(
          AppEndpoint.getIndustriesList(),
          queryParameters: {'languageCode': appPrefs.languageCode});
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<IndustryModel>((i) => IndustryModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getLanguageAvailable() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false).get(
          AppEndpoint.getLanguageAvailable(),
          queryParameters: {'available': 1});
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<LanguageModel>((i) => LanguageModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getCurrencies() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .get(AppEndpoint.getCurrencies(), queryParameters: {'available': 1});
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<CurrencyModel>((i) => CurrencyModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getLanguageForSpeakAvailable() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false).get(
          AppEndpoint.getLanguageForSpeakAvailable(),
          queryParameters: {'availableForSpeak': 1});
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<LanguageModel>((i) => LanguageModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getTerminalsFromPro(terminalType) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getTerminalsFromPro(),
              queryParameters: {'terminalType': terminalType});
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => Terminal.fromJson(e)).toList());
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getAllTerminalFromAdmin(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getAllTerminalFromAdmin(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => Terminal.fromJson(e)).toList());
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> v2_getCurrentTerminalsOfPlaylistFromPro(
      params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.v2_getCurrentTerminalsOfPlaylistFromPro(),
              queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => Terminal.fromJson(e)).toList());
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getVideoConfigFromPlayerVimeo(vimeoId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false).get(
          AppEndpoint.getVideoConfigFromPlayerVimeo(),
          queryParameters: {'videoId': vimeoId});
      return NetworkResponse.fromResponse(response,
          converter: (json) => VimeoConfig.fromJson(json));
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> updateTerminalFromPro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .put(AppEndpoint.updateTerminalFromPro(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> v2_sendPropertyToTerminal(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.v2_sendPropertyToTerminal(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> v2_removePropertyFromTerminal(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .delete(AppEndpoint.v2_removePropertyFromTerminal(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> updateProduct(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .put(AppEndpoint.updateProduct(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> takeMissionFromSeller(missionId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.takeMissionFromSeller(),
              data: {'missionId': missionId});
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> googlePlaceAutoComplete(String keyword,
      {String? countryCode, List<String>? types}) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      var queryParameters = {
        'value': keyword,
        'types': types ?? ['address']
      };
      if (countryCode != null) {
        queryParameters.addAll({
          'country': countryCode,
        });
      }
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.googlePlaceAutoComplete(),
              queryParameters: queryParameters);
      if (response.data['status'] == 'OK') {
        return NetworkResponse.fromResponse(response,
            prefix: 'predictions',
            converter: (json) => (json as List<dynamic>)
                .map<AutocompletePrediction>(
                    (i) => AutocompletePrediction.fromJson(i))
                .toList());
      } else {
        return NetworkResponse();
      }
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> googlePlaceSeachPlaceByText(String keyword,
      [String? types]) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false).get(
          'https://maps.googleapis.com/maps/api/place/textsearch/json',
          queryParameters: {
            'query': keyword,
            'key': googleApiKey,
            'type': types
          });
      return NetworkResponse.fromResponse(response,
          prefix: 'results',
          converter: (json) => (json as List<dynamic>)
              .map<SeachPlaceResultModel>(
                  (i) => SeachPlaceResultModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> googlePlaceSeachPlaceDetailById(placeId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false).get(
          'https://maps.googleapis.com/maps/api/place/details/json',
          queryParameters: {'place_id': placeId, 'key': googleApiKey});
      return NetworkResponse.fromResponse(response,
          prefix: 'result',
          converter: (json) => SeachPlaceResultDetailModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> googleGeocode(latlng) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false).get(
          'https://maps.googleapis.com/maps/api/geocode/json',
          queryParameters: {'latlng': latlng, 'key': googleApiKey});
      return NetworkResponse.fromResponse(response,
          prefix: 'results',
          converter: (json) => (json as List<dynamic>)
              .map<SeachPlaceResultDetailModel>(
                  (i) => SeachPlaceResultDetailModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> googlePlaceSearchById(String placeId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.googlePlaceSearchById(),
              queryParameters: {'placeId': placeId});
      return NetworkResponse.fromResponse(response,
          prefix: '', converter: (json) => DetailsResponse.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> arckipelgooglePlaceSearch(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.googlePlaceSearch(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          prefix: 'results',
          converter: (json) => (json as List<dynamic>)
              .map<SeachPlaceResultModel>(
                  (i) => SeachPlaceResultModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> arckipelgooglePlaceSeachPlaceDetailById(
      params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.googlePlaceSearch(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          prefix: 'result',
          converter: (json) => SeachPlaceResultDetailModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getProductCategories() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getProductCategories(),
              queryParameters: {'display': 1});
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<ProductCategory>((i) => ProductCategory.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getProductsFromPro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getProductsFromPro(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<ProductModel>((i) => ProductModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getProductOfProFromSA(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getProductOfProFromSA(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<ProductModel>((i) => ProductModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getProductOfUserFromSA(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getProductOfUserFromSA(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<ProductModel>((i) => ProductModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getStatusList() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getStatusList());
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<ProductStatus>((i) => ProductStatus.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getAllPublicEventsFromSearch(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .get(AppEndpoint.getAllPublicEventsFromSearch(),
              queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<PublishEvent>((i) => PublishEvent.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getAllPublicEventsAroundMe(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .get(AppEndpoint.getAllPublicEventsAroundMe(),
              queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<PublishEvent>((i) => PublishEvent.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getPublicEventsListFromUser(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .get(AppEndpoint.getPublicEventsListFromUser(),
              queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<PublishEvent>((i) => PublishEvent.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getSuggestionEventsFromUser(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .get(AppEndpoint.getSuggestionEventsFromUser(),
              queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<PublishEvent>((i) => PublishEvent.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getPublicEventsCategories(languageCode) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .get(AppEndpoint.getPublicEventsCategories(),
              queryParameters: {'languageCode': languageCode});
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<PublishEventCategory>(
                  (i) => PublishEventCategory.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getFavoritePublicEventsCategoriesFromUser(
      languageCode) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .get(AppEndpoint.getFavoritePublicEventsCategoriesFromUser(),
              queryParameters: {'languageCode': languageCode});
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<PublishEventCategory>(
                  (i) => PublishEventCategory.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getLikedPublicEventsFromUser() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .get(AppEndpoint.getLikedPublicEventsFromUser());
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<PublishEvent>((i) => PublishEvent.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getTicketListFromPublicEvent(publicEventId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .get(AppEndpoint.getTicketListFromPublicEvent(),
              queryParameters: {'publicEventId': publicEventId});
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<TicketInfoModel>((i) => TicketInfoModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> addUserLikeToPublicEvent(publicEventId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .post(AppEndpoint.addUserLikeToPublicEvent(),
              data: {'publicEventId': publicEventId});
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> setFavoriteCatForUser(catId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .post(AppEndpoint.setFavoriteCatForUser(), data: {'catId': catId});
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> removeFavoriteCatForUser(catId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .delete(AppEndpoint.removeFavoriteCatForUser(),
              data: {'catId': catId});
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> addSeenSuggestionEventFromUser(
      publicEventId, utcModifier) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .post(AppEndpoint.addSeenSuggestionEventFromUser(), data: {
        'publicEventId': publicEventId,
        'utcModifier': utcModifier
      });
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> bookFreeTicketForPublicEvents(
      arckipelTicketId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .post(AppEndpoint.bookFreeTicketForPublicEvents(),
              data: {'arckipelTicketId': arckipelTicketId});
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getAllowedFeaturesForOowooApp() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .get(AppEndpoint.getAllowedFeaturesForOowooApp());
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<AllowedFeatureModel>((i) => AllowedFeatureModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> v2_getDashboardConfigFromPro() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .get(AppEndpoint.v2_getDashboardConfigFromPro(),
              queryParameters: {'languageCode': appPrefs.languageCode});
      return NetworkResponse.fromResponse(response,
          converter: (json) => DashboardConfig.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> createCustomerCardStripe(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .post(AppEndpoint.createCustomerCardStripe(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => PaymentCardStripe.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> deleteCustomerCardStripe(cardId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .delete(AppEndpoint.deleteCustomerCardStripe(),
              data: {'cardId': cardId});
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getCustomerCardsStripe(page, pageSize) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .get(AppEndpoint.getCustomerCardsStripe(),
              queryParameters: {'page': page, 'page_size': pageSize});
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<PaymentCardStripe>((i) => PaymentCardStripe.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> setCustomerCardDefaultStripe(cardId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .put(AppEndpoint.setCustomerCardDefaultStripe(),
              data: {'cardId': cardId});
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> becomeSeller(confirmed) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .post(AppEndpoint.becomeSeller(), data: {'confirmed': confirmed});
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> updateImageForBecomeSeller(fileType, path) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      String fileName = path.split('/').last;
      FormData formData = FormData.fromMap({
        "fileType": fileType,
        "fileName": MultipartFile.fromBytes(File(path).readAsBytesSync(),
            filename: fileName),
      });
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .post(AppEndpoint.updateImageForBecomeSeller(), data: formData);
      return NetworkResponse.fromResponse(response,
          value: response.data['values']['fileName']);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> quitSellerProgram(temporary) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .post(AppEndpoint.quitSellerProgram(),
              data: {'temporary': temporary});
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> recoverySellerProgram() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .post(AppEndpoint.recoverySellerProgram());
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getTncOowooApp() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false).get(
          AppEndpoint.getTncOowooApp(),
          queryParameters: {'languageCode': appPrefs.languageCode});
      return NetworkResponse.fromResponse(response,
          converter: (json) => json['text']);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getTncOowooSeller() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false).get(
          AppEndpoint.getTncOowooSeller(),
          queryParameters: {'languageCode': appPrefs.languageCode});
      return NetworkResponse.fromResponse(response,
          converter: (json) => json['text']);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> birthsOnThisDay(date) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .get('https://byabbe.se/on-this-day/$date/births.json');
      return NetworkResponse.fromResponse(response,
          prefix: 'births',
          converter: (json) => (json as List<dynamic>)
              .map<OnThisDayModel>((i) => OnThisDayModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> deathsOnThisDay(date) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .get('https://byabbe.se/on-this-day/$date/deaths.json');
      return NetworkResponse.fromResponse(response,
          prefix: 'deaths',
          converter: (json) => (json as List<dynamic>)
              .map<OnThisDayModel>((i) => OnThisDayModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> eventsOnThisDay(date) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .get('https://byabbe.se/on-this-day/$date/events.json');
      return NetworkResponse.fromResponse(response,
          prefix: 'events',
          converter: (json) => (json as List<dynamic>)
              .map<OnThisDayModel>((i) => OnThisDayModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> pexelsSearch(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true,
              isAuthorizationCustom: true,
              token: PEXEL_API_KEY)
          .get('https://api.pexels.com/v1/search', queryParameters: params);
      return NetworkResponse.fromResponse(response,
          prefix: 'photos',
          converter: (json) => (json as List<dynamic>)
              .map<PexelPhotoModel>((i) => PexelPhotoModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> weatherForecast(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
        requiredToken: false,
        enableErrorHandler: false,
      ).get('https://api.weatherapi.com/v1/forecast.json',
          queryParameters: params);
      return NetworkResponse.fromResponse(response,
          prefix: 'forecast',
          converter: (json) => WeatherForecast.fromJson(json));
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> weatherHistory(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
        requiredToken: false,
        enableErrorHandler: false,
      ).get('https://api.weatherapi.com/v1/history.json',
          queryParameters: params);
      return NetworkResponse.fromResponse(response,
          prefix: 'forecast',
          converter: (json) => WeatherForecast.fromJson(json));
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getMissionsFromSeller(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getMissionsFromSeller(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<SellerMissionModel>((i) => SellerMissionModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getMissionTypes(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getMissionTypes(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<MissionTypeModel>((i) => MissionTypeModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getOoBRPlaceInfoById(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getOoBRPlaceInfoById(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => BrPlaceModel.fromJson(json));
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getOoBRPlacesAroundMe(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getOoBRPlacesAroundMe(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<BrPlaceModel>((i) => BrPlaceModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getOoBRPlacesByFilterValues(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getOoBRPlacesByFilterValues(),
              queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<BrPlaceModel>((i) => BrPlaceModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getFavoriteOobrPlaces() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getFavoriteOobrPlaces());
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<BrPlaceModel>((i) => BrPlaceModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> updateFilterValueForOobr(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.updateFilterValueForOobr(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => json['updateFilterValueForOobr']);
    } on DioError catch (e) {
      if (e.response != null &&
          e.response!.statusCode == 400 &&
          e.response!.data != null) {
        return NetworkResponse.fromResponse(e.response!,
            value: e.response!.data['error']);
      }
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getPromotedVideosForBar(oobrPlaceId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getPromotedVideosForBar(),
              queryParameters: {'oobrPlaceId': oobrPlaceId});
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List<dynamic>).map<String>((i) => i).toList());
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getPromotedVideosForOobrPlaces(lat, lng) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getPromotedVideosForOobrPlaces(),
              queryParameters: {'lat': lat, 'lng': lng});
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<BrPromotedVideoModel>(
                  (i) => BrPromotedVideoModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getPromotedVideosForOoh(lat, lng) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getPromotedVideosForOoh(),
              queryParameters: {'lat': lat, 'lng': lng});
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<BrPromotedVideoModel>(
                  (i) => BrPromotedVideoModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getOoBRCategories(languageCode) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getOoBRCategories(),
              queryParameters: {'languageCode': languageCode});
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<BrPlaceCateModel>((i) => BrPlaceCateModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getOoBRFilters(languageCode) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getOoBRFilters(),
              queryParameters: {'languageCode': languageCode});
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<BrPlaceFilterModel>((i) => BrPlaceFilterModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> checkBarGooglePlaceIdByContributor(
      googlePlaceId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.checkBarGooglePlaceIdByContributor(),
              queryParameters: {'googlePlaceId': googlePlaceId});
      return NetworkResponse.fromResponse(response, value: '');
    } on DioError catch (e) {
      if (e.response != null &&
          e.response!.statusCode == 400 &&
          e.response!.data != null) {
        return NetworkResponse.fromResponse(e.response!,
            value: e.response!.data['oobrPlaceId']);
      }
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> createNewOobrPlaceByContributor(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.createNewOobrPlaceByContributor(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> addOobrPlaceToFavorites(oobrPlaceId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.addOobrPlaceToFavorites(),
              data: {'oobrPlaceId': oobrPlaceId});
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getOobrPlaceSchedules(oobrPlaceId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getOobrPlaceSchedules(),
              queryParameters: {'oobrPlaceId': oobrPlaceId});
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<BrPlaceScheduleModel>(
                  (i) => BrPlaceScheduleModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getOobrPlaceMenuList(
      oobrPlaceId, languageCode) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getOobrPlaceMenuList(), queryParameters: {
        'oobrPlaceId': oobrPlaceId,
        'languageCode': languageCode
      });
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<BrPlaceMenu>((i) => BrPlaceMenu.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getOobrPlaceMenuContent(
      oobrPlaceId, languageCode) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getOobrPlaceMenuContent(), queryParameters: {
        'oobrPlaceId': oobrPlaceId,
        'languageCode': languageCode
      });
      return NetworkResponse.fromResponse(response,
          converter: (json) => BrPlaceMenuContent.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getOptionsForItem(itemId, languageCode) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getOptionsForItem(), queryParameters: {
        'itemId': itemId,
        'languageCode': languageCode
      });
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<PlaceMenuItemOption>((i) => PlaceMenuItemOption.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getAllergensForItem(itemId, languageCode) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getAllergensForItem(), queryParameters: {
        'itemId': itemId,
        'languageCode': languageCode
      });
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<PlaceMenuAllergens>((i) => PlaceMenuAllergens.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getContactsList(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getContactsList(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<ContactModel>((i) => ContactModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> addUserInContactsList(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.addUserInContactsList(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => ContactModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> addUserOrProToContactListByFirebaseId(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.addUserOrProToContactListByFirebaseId(),
              data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => ContactModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> createFirebaseDynamicLink(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .post(AppEndpoint.createFirebaseDynamicLink(), data: params);
      return NetworkResponse.fromResponse(response, converter: (json) => json);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> deleteContact(id) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .delete(AppEndpoint.deleteContact(), data: {'id': id});
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> updateCommentForContact(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .put(AppEndpoint.updateCommentForContact(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getExistingUserByPhone(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getExistingUserByPhone(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => ContactModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> createOrderForOobrPlace(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.createOrderForOobrPlace(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<UserModel>((i) => UserModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getAnythingFromQr(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getAnythingFromQr(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => QrDataModel.fromJson(json));
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getDetailOobrInvitations(oobrEventId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getDetailOobrInvitations(),
              queryParameters: {'oobrEventId': oobrEventId});
      return NetworkResponse.fromResponse(response,
          converter: (json) => BrPlaceInviteModel.fromJson(json));
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> inviteContactsToOobrPlace(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.inviteContactsToOobrPlace(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> answerOobrInvitation(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.answerOobrInvitation(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getEmergencyInfos(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getEmergencyInfos(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => EmergencyResult.fromJson(json));
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> sendEmergencyRequest(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.sendEmergencyRequest(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> createSharedPcEvent(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.createSharedPcEvent(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => json['id']);
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getPcEventFromUser(pcEventId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getPcEventFromUser(),
              queryParameters: {'pcEventId': pcEventId});
      return NetworkResponse.fromResponse(response,
          converter: (json) => PeEventModel.fromJson(json));
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> setThumbnailForPcEvent(path, pcEventId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      String fileName = path.split('/').last;
      FormData data = FormData.fromMap({
        'pcEventId': pcEventId,
        "fileName": MultipartFile.fromBytes(File(path).readAsBytesSync(),
            filename: fileName),
      });
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.setThumbnailForPcEvent(), data: data);
      return NetworkResponse.fromResponse(response,
          converter: (json) => json['fileName']);
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> shareCalendarToUsers(params) =>
      throw UnimplementedError();

  @override
  Future<NetworkResponse> getHomesAroundMe(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getHomesAroundMe(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<HomePlaceModel>((i) => HomePlaceModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> whatsNext(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.whatsNext(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => WhatNextModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> generateToken(channelName, expiredTime) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.generateVideoCallToken(),
              data: {'channel': channelName});
      return NetworkResponse.fromResponse(response,
          converter: (json) => AgoraToken.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getHomelidoPropertyCategories(languageCode) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getHomelidoPropertyCategories(),
              queryParameters: {'languageCode': languageCode});
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<HomelidoPropertyCategory>(
                  (i) => HomelidoPropertyCategory.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getPropertiesFromPro(languageCode) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getPropertiesFromPro(),
              queryParameters: {'languageCode': languageCode});
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<HomelidoProperty>((i) => HomelidoProperty.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> v2_getCurrentPropertiesOfTerminal(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.v2_getCurrentPropertiesOfTerminal(),
              queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<HomelidoProperty>((i) => HomelidoProperty.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> createHomlidoMeeting(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.createHomelidoMeeting(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => IdResult.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getHomelidoMeetingDetails(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getHomelidoMeetingDetails(),
              queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => HomelidoMeeting.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> answerToHomelidoVisitRequest(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .put(AppEndpoint.answerToHomelidoVisitRequest(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getNumberOfSalesFromSellers(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getNumberOfSalesFromSellers(),
              queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => NumberOfSaleModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> setBankAccountFromUser(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.setBankAccountFromUser(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => BankAccountModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> updateBankInfosFromSeller(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .put(AppEndpoint.updateBankInfosFromSeller(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => BankAccountModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getAccountTypes() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getAccountTypes());
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List)
              .map((e) => BankAccountTypeModel.fromJson(e))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getBankInfosFromSeller() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getBankInfosFromSeller());
      return NetworkResponse.fromResponse(response,
          converter: (json) => BankAccountModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> addUserOrProToTrackingPeople(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.addUserOrProToTrackingPeople(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List)
              .map((e) => TrackingInfoModel.fromJson(e))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getTrackingInfosForMeeting(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getTrackingInfosForMeeting(),
              queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List)
              .map((e) => TrackingInfoModel.fromJson(e))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> updateTrackingInfosForMeeting(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .put(AppEndpoint.updateTrackingInfosForMeeting(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List)
              .map((e) => TrackingInfoModel.fromJson(e))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getLearnMoreTrackingVideo() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false).get(
          AppEndpoint.getLearnMoreTrackingVideo(),
          queryParameters: {'languageCode': appPrefs.languageCode});
      return NetworkResponse.fromResponse(response, converter: (json) => json);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getReminderTypes() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getReminderTypes(),
              queryParameters: {'languageCode': appPrefs.languageCode});
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => ReminderType.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getOowooMoveProperties(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getOowooMoveProperties(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => MoveModel.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getOowooVideoByTypeId(typeId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getOowooVideoByTypeId(), queryParameters: {
        'typeId': typeId,
        'languageCode': appPrefs.languageCode
      });
      return NetworkResponse.fromResponse(response,
          converter: (json) => VideoUrl.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getCalmByCat(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getCalmByCat(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<CalmModel>((i) => CalmModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getCalmCategories() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getCalmCategories(),
              queryParameters: {'languageCode': appPrefs.languageCode});
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<CalmCate>((i) => CalmCate.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getSubscribersForCalmId(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getSubscribersForCalmId(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json['subscribers'] as List<dynamic>)
              .map<CalmSubscriber>((i) => CalmSubscriber.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> subscribeToCalmId(calmId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.subscribeToCalmId(), data: {'calmId': calmId});
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> testSendNotificationToPro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.testSendNotificationToPro(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> testSendNotificationToUser(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.testSendNotificationToUser(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> notifVideoCallProFromUser(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.notifVideoCallProFromUser(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> notifVideoCallUserFromPro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.notifVideoCallUserFromPro(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getReviewsFromPro(proId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getReviewsFromPro(),
              queryParameters: {'proId': proId});
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<ReviewModel>((i) => ReviewModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> cancelTicketByUser(
      ticketUniqueId, status, comment) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.cancelTicketByUser(),
              data: {'ticketUniqueId': ticketUniqueId});
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> confirmTicketByUser(
      ticketUniqueId, status, comment) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.confirmTicketByUser(), data: {
        'ticketUniqueId': ticketUniqueId,
        'status': status,
        'comment': comment
      });
      return NetworkResponse.fromResponse(response,
          converter: (json) => TicketInfoModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> deleteEventsFromUser(ticketUniqueId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .delete(AppEndpoint.deleteEventsFromUser(), data: {
        'events': [ticketUniqueId]
      });
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getAllEventsFromUser() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getAllEventsFromUser(),
              queryParameters: {'catLanguageCode': appPrefs.languageCode});
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<EventInfoModel>((i) => EventInfoModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getEventInfoFromUser(eventUniqueId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getEventInfoFromUser(), queryParameters: {
        'catLanguageCode': appPrefs.languageCode,
        'eventUniqueId': eventUniqueId
      });
      return NetworkResponse.fromResponse(response,
          converter: (json) => EventInfoModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getQueueInfoFromUser(ticketUniqueId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getQueueInfoFromUser(), queryParameters: {
        'catLanguageCode': appPrefs.languageCode,
        'ticketUniqueId': ticketUniqueId
      });
      return NetworkResponse.fromResponse(response,
          converter: (json) => EventQueueModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> ticketUserCallBack(ticketUniqueId, duration) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.ticketUserCallBack(),
              data: {'ticketUniqueId': ticketUniqueId, 'duration': duration});
      return NetworkResponse.fromResponse(response,
          converter: (json) => TicketInfoModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getUserInfoByFirebaseId(firebaseId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getUserInfoByFirebaseId(),
              queryParameters: {'firebaseId': firebaseId});
      return NetworkResponse.fromResponse(response,
          converter: (json) => UserModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getProInfoByFirebaseId(firebaseId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getProInfoByFirebaseId(),
              queryParameters: {'firebaseId': firebaseId});
      return NetworkResponse.fromResponse(response,
          converter: (json) => ProsModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> addToFavourite(proId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.addToFavourite(), data: {'proId': proId});
      return NetworkResponse.fromResponse(response, value: true);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getFavouriteForUser() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getFavouriteForUser());
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<ProsModel>((i) => ProsModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> removeFromFavourite(proId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .delete(AppEndpoint.removeFromFavourite(), data: {'proId': proId});
      return NetworkResponse.fromResponse(response, value: true);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> updateHomelidoMeeting(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .put(AppEndpoint.updateHomelidoMeeting(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getPcEventFromPro(pcEventId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getPcEventFromPro(),
              queryParameters: {'pcEventId': pcEventId});
      return NetworkResponse.fromResponse(response,
          converter: (json) => PeEventModel.fromJson(json));
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> deleteCodeFromLog(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .put(AppEndpoint.deleteCodeFromLog(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> createCode(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.createCode(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => DigicodeCodeModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> updateLiveCode(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .put(AppEndpoint.updateLiveCode(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> shareCodeDigicode(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.shareCodeDigicode(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> deleteLiveCode(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .delete(AppEndpoint.deleteLiveCode(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getCodesFromPro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getCodesFromPro(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List)
              .map((e) => DigicodeCodeModel.fromJson(e))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getDigicodesFromPro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getDigicodesFromPro(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => DigicodeModel.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getDigicodeById(id) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getDigicodeById(), queryParameters: {'id': id});
      return NetworkResponse.fromResponse(response,
          converter: (json) => DigicodeModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> checkDigicodeBySerialAndToken(
      productSerial, authcode) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              options: BaseOptions(headers: {'auth-code': authcode}),
              requiredToken: true,
              token: await appPrefs.getNormalToken())
          .get(AppEndpoint.checkDigicodeBySerialAndToken(),
              queryParameters: {'productSerial': productSerial});
      return NetworkResponse.fromResponse(response,
          converter: (json) => DigicodeCheck.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> linkDigicodeToPro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.linkDigicodeToPro(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> linkDigicodeToProV2(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.linkDigicodeToProV2(), data: params);
      return NetworkResponse.fromResponse(response,
          value: UpdateInfoResult(status: response.statusCode == 200));
    } on DioError catch (e) {
      if (e.response?.data != null && e.response!.data['error'] is String) {
        return NetworkResponse.fromResponse(e.response!,
            value: UpdateInfoResult(
                status: false, msg: e.response!.data['error']));
      }
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> linkTerminalToProV2(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.linkTerminalToProV2(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getDigicodesLogs(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getDigicodesLogs(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => DigicodeLogModel.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getPlacesFromPro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getPlacesFromPro());
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => PlaceModel.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getPlatformsList(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .get(AppEndpoint.getPlatformsList(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => PlatformModel.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getPlatformsListDoubleAuth(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getPlatformsListDoubleAuth(),
              queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => PlatformModel.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> activateDoubleAuthForPlatform(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.activateDoubleAuthForPlatform(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> createPlace(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.createPlace(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => PlaceModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getPlaceCatByLang(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getPlaceCatByLang(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => PlaceCatModel.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> unlockDigicode(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.unlockDigicode(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> checkDigicodeOnline(digicodeId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.checkDigicodeOnline(),
              queryParameters: {'digicodeId': digicodeId});
      return NetworkResponse.fromResponse(response,
          prefix: 'status', converter: (json) => json);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> setLanguagesForPro(proLanguageCode) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.setLanguagesForPro(),
              data: {'proLanguageCode': proLanguageCode});
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> setMainLanguageForPro(proLanguageCode) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.setMainLanguageForPro(),
              data: {'proLanguageCode': proLanguageCode});
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getAllEventsFromPro() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getAllEventsFromPro(),
              queryParameters: {'languageCode': appPrefs.languageCode});
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => EventInfoModel.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getAllServicesOfProFromPro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getAllServicesOfProFromPro(),
              queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => ProServiceModel.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> callNextTicket(serviceId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.callNextTicket(), data: {'serviceId': serviceId});
      return NetworkResponse.fromResponse(response,
          converter: (json) => TicketInfoModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> cancelTicketByPro(ticketUniqueId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.cancelTicketByPro(),
              data: {'ticketUniqueId': ticketUniqueId});
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> canceledByProAfterCallBack(ticketUniqueId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.canceledByProAfterCallBack(),
              data: {'ticketUniqueId': ticketUniqueId});
      return NetworkResponse.fromResponse(response,
          converter: (json) => EventInfoModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> confirmTicketByPro(
      ticketUniqueId, status, comment) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.confirmTicketByPro(), data: {
        'ticketUniqueId': ticketUniqueId,
        'confirm': status,
        'comment': comment
      });
      return NetworkResponse.fromResponse(response,
          converter: (json) => EventInfoModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> createTicketByPro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.createTicketByPro(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => TicketInfoModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getAllServicesOfProFromUser(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getAllServicesOfProFromUser(),
              queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => ProServicesBusiness.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getAllServicesAroundMe(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getAllServicesAroundMe(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List)
              .map((e) => ServicesAroundMeModel.fromJson(e))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> createTicketByUser(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.createTicketByUser(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => TicketInfoModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> declareUserAsAbsentFromPro(ticketUniqueId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.declareUserAsAbsentFromPro(),
              data: {'ticketUniqueId': ticketUniqueId});
      return NetworkResponse.fromResponse(response,
          converter: (json) => EventInfoModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> deleteEventsFromPro(ticketUniqueId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .delete(AppEndpoint.deleteEventsFromPro(), data: {
        'events': [ticketUniqueId]
      });
      return NetworkResponse.fromResponse(response,
          converter: (json) => EventInfoModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getEventInfoFromPro(eventUniqueId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getEventInfoFromPro(),
              queryParameters: {'eventUniqueId': eventUniqueId});
      return NetworkResponse.fromResponse(response,
          converter: (json) => EventInfoModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getListTimeFramesByServiceForDay(
      dateToday, serviceId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getListTimeFramesByServiceForDay(),
              queryParameters: {
            'dateToday': dateToday,
            'serviceId': serviceId
          });
      return NetworkResponse.fromResponse(response,
          converter: (json) => ListTimeFrameModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getServiceAvailabilityForMonth(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getServiceAvailabilityForMonth(),
              queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List)
              .map((e) => ServiceAvailabilityModel.fromJson(e))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> startTicket(ticketUniqueId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.startTicket(),
              data: {'ticketUniqueId': ticketUniqueId});
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> stopTicket(ticketUniqueId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.stopTicket(),
              data: {'ticketUniqueId': ticketUniqueId});
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> ticketUserNotResponse(ticketUniqueId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.ticketUserNotResponse(),
              data: {'ticketUniqueId': ticketUniqueId});
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> updateDelay(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.updateDelay(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List)
              .map((e) => ServiceDelayModel.fromJson(e))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getLoginSessions(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getLoginSessions(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => LoginSession.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getLoginSessionsById(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getLoginSessionsById(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => LoginSession.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> createNonExistingRandomCode(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.createNonExistingRandomCode(),
              queryParameters: params);
      return NetworkResponse.fromResponse(response, converter: (json) => json);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> revokeLoginSession(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.revokeLoginSession(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> allowPendingLoginOnPlatformByQrCode(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.allowPendingLoginOnPlatformByQrCode(),
              data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> allowPendingLoginOnPlatformById(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.allowPendingLoginOnPlatformById(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> activatePourDevice(deviceId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.activatePourDevice(), data: {'deviceId': deviceId});
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      if (e.response?.statusCode == 400)
        return NetworkResponse.fromResponse(e.response!,
            value: e.response!.data['error']);
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> createPurchaseByCardOnFileStripe(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.createPurchaseByCardOnFileStripe(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<PaymentInfoModel>((i) => PaymentInfoModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getBgVideo(countryCode) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .get(AppEndpoint.getBgVideo(),
              queryParameters: {'countryCode': countryCode});
      return NetworkResponse.fromResponse(response,
          converter: (json) => json['videoUrl']);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getCurrencyAvailableForToken(tokenType) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false).get(
          AppEndpoint.getCurrencyAvailableForToken(),
          queryParameters: {'tokenType': tokenType});
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List<dynamic>).map<String>((i) => i).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getCurrentTokenValue(tokenType,
      {currency = 'EUR'}) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false).get(
          AppEndpoint.getCurrentTokenValue(),
          queryParameters: {'tokenType': tokenType, 'currency': currency});
      return NetworkResponse.fromResponse(response,
          converter: (json) => double.parse(json.toString()));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getHistoryFromUser() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .get(AppEndpoint.getHistoryFromUser());
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<History>((i) => History.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getPmbDevicesAroundMe(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .get(AppEndpoint.getPmbDevicesAroundMe(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<PmbDevice>((i) => PmbDevice.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getWalletInfo() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getWalletInfo());
      return NetworkResponse.fromResponse(response,
          converter: (json) => WalletInfo.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> ipAPI() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: false, baseUrl: 'http://ip-api.com/')
          .get('json');
      return NetworkResponse.fromResponse(response,
          converter: (json) => IpInfo.fromJson(json), prefix: '');
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> scanDeviceQr(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .get(AppEndpoint.scanDeviceQr(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => ScanQr.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> checkAndAddNewContact(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .post(AppEndpoint.checkAndAddNewContact(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> v2_addItemToPlaylist(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.v2_addItemToPlaylist(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => PlaylistItemModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> v2_createPlaylistFromPro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.v2_createPlaylistFromPro(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => PlaylistModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> v2_deletePlaylistFromPro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .delete(AppEndpoint.v2_deletePlaylistFromPro(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> v2_getItemContentFromPlaylist(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .get(AppEndpoint.v2_getItemContentFromPlaylist(),
              queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<PlaylistItemModel>((i) => PlaylistItemModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> v2_getPlaylistFromPro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .get(AppEndpoint.v2_getPlaylistFromPro(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<PlaylistModel>((i) => PlaylistModel.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  // @override
  // Future<NetworkResponse> v2_getPlaylistsFromTerminal(params) async {
  //   bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
  //   if (isDisconnect) return NetworkResponse.withDisconnect();
  //   try {
  //     final token = await appPrefs.getNormalToken();
  //     Response response = await AppClientsWeb(requiredToken: true, token: token)
  //         .get(AppEndpoint.v2_getPlaylistsFromTerminal(),
  //             queryParameters: params);
  //     return NetworkResponse.fromResponse(response,
  //         converter: (json) => (json as List<dynamic>)
  //             .map<PlaylistModel>((i) => PlaylistModel.fromJson(i))
  //             .toList());
  //   } on DioError catch (e) {
  //     return NetworkResponse.withErrorRequest(e);
  //   } catch (e) {
  //     return NetworkResponse.withErrorConvert(e);
  //   }
  // }

  @override
  Future<NetworkResponse> v2_removeItemFromPlaylist(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      final token = await appPrefs.getNormalToken();
      Response response = await AppClientsWeb(requiredToken: true, token: token)
          .delete(AppEndpoint.v2_removeItemFromPlaylist(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> v2_linkPlaylistToTerminalForPro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.v2_linkPlaylistToTerminalForPro(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> v2_addScheduleForPlaylist(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.v2_addScheduleForPlaylist(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> v2_updateScheduleForPlaylist(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .put(AppEndpoint.v2_updateScheduleForPlaylist(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> v2_removeScheduleForPlaylist(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .delete(AppEndpoint.v2_removeScheduleForPlaylist(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> v2_updateOrderItemsFromPlaylist(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .put(AppEndpoint.v2_updateOrderItemsFromPlaylist(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> v2_getProblemTypesList(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.v2_getProblemTypesList(), queryParameters: params);

      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<ProblemType>((i) => ProblemType.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getFaqGroupsFromPlatformId(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getFaqGroupsFromPlatformId(),
              queryParameters: params);

      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<FaqGroup>((i) => FaqGroup.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> clickOnFaq(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.clickOnFaq(), queryParameters: params);

      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<ProblemType>((i) => ProblemType.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getProblemTypesForGroupId(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getProblemTypesForGroupId(),
              queryParameters: params);

      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<ProblemType>((i) => ProblemType.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getFaqForProblemType(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getFaqForProblemType(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<FaqItem>((i) => FaqItem.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> v2_getMyTicketsFromCustomer(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.v2_getMyTicketsFromCustomer(),
              queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        prefix: '',
        converter: (json) => ListTicket.fromJson(json),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> v2_postTicketByCustomer(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.v2_postTicketByCustomer(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => TicketDetail.fromJson(json));
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> v2_getMyTicketsFromAgent(ticketStatusId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.v2_getMyTicketsFromAgent(), queryParameters: {
        'languageCode': appPrefs.languageCode,
        'ticketStatusId': ticketStatusId,
      });
      return NetworkResponse.fromResponse(
        response,
        prefix: '',
        converter: (json) => ListTicket.fromJson(json),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> v2_getAgentList() async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.v2_getAgentList(), queryParameters: {
        'languageCode': appPrefs.languageCode,
      });
      return NetworkResponse.fromResponse(
        response,
        converter: (json) =>
            (json as List).map((e) => AgentModel.fromJson(e)).toList(),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> v2_answerToTicketFromAgent(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.v2_answerToTicketFromAgent(), data: params);
      return NetworkResponse.fromResponse(
        response,
        value: response.statusCode == 200,
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> v2_answerToTicketFromCustomer(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.v2_answerToTicketFromCustomer(), data: params);
      return NetworkResponse.fromResponse(
        response,
        value: response.statusCode == 200,
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> v2_assignTicketToAgents(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.v2_assignTicketToAgents(), data: params);
      return NetworkResponse.fromResponse(
        response,
        value: response.statusCode == 200,
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getAnswersOfTicket(ticketId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getAnswersOfTicket(), queryParameters: {
        'ticketId': ticketId,
      });
      return NetworkResponse.fromResponse(
        response,
        converter: (json) =>
            (json as List).map((e) => TicketAnswer.fromJson(e)).toList(),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getLinksListFromMainLink(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .get(AppEndpoint.getLinksListFromMainLink(), queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) => MainLink.fromJson(json),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> addLocationForUser(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.addLocationForUser(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => LocationModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> createPurchaseByPaymentMethodStripe(params) {
    // TODO: implement createPurchaseByPaymentMethodStripe
    throw UnimplementedError();
  }

  @override
  Future<NetworkResponse> createPurchaseByTokenStripe(params) {
    // TODO: implement createPurchaseByTokenStripe
    throw UnimplementedError();
  }

  @override
  Future<NetworkResponse> getAllEventsFromEventsWebsite(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getAllEventsFromEventsWebsite(),
              queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => PublishEvent.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getCategoriesFromEventsWebsite(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getCategoriesFromEventsWebsite(),
              queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List)
              .map((e) => PublishEventCategory.fromJson(e))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getHashtagsList(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getHashtagsList(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => HashTagModel.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getLocationFromUser(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getLocationFromUser(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => LocationModel.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getMaincatList(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getMaincatList(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => MainCatModel.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getResultsByCatFromEventsWebsite(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getResultsByCatFromEventsWebsite(),
              queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => PublishEvent.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getResultsFromFilters(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getResultsFromFilters(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => ProsModel.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getResultsFromSearch(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getResultsFromSearch(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => ProsModel.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getSpecList(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getSpecList(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => SpecCatModel.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getSubcatList(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getSubcatList(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => SubCatModel.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> removeLocationForUser(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.removeLocationForUser(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> setLocationDefault(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .put(AppEndpoint.setLocationDefault(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> updateLocationForUser(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .put(AppEndpoint.updateLocationForUser(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> loginTerminal(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .post(AppEndpoint.loginTerminal(), data: params);
      return NetworkResponse.fromResponse(response, value: response.data);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getVideoPlaylistsFromTerminal(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getVideoPlaylistsFromTerminal(),
              queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
      );
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getServicesListFromTerminal() async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getServicesListFromTerminal());
      return NetworkResponse.fromResponse(response,
          converter: (json) => QueueOowooModel.listFromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getNextTicketAvailableForQueueFromTerminal(id) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(
        AppEndpoint.getNextTicketAvailableForQueueFromTerminal(),
        queryParameters: {'serviceId': id},
      );
      return NetworkResponse.fromResponse(response,
          converter: (json) => TicketModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> cancelNextTicketAvailableForQueueFromTerminal(
      id) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(
        AppEndpoint.cancelNextTicketAvailableForQueueFromTerminal(),
        data: {'ticketUniqueId': id},
      );
      return NetworkResponse.fromResponse(
        response,
        value: response.data,
      );
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getPropertiesDetailsByList(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getPropertiesDetailsByList(),
              queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List)
              .map((e) => HomelidoPropertyInfo.fromJson(e))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> v2_getPlaylistsFromTerminal(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.v2_getPlaylistsFromTerminal());
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => PlaylistModel.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getListOfProsFromAdmin(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getListOfProsFromAdmin(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => ProInfo.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getProInfosFromSA(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getProInfosFromSA(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => ProInfo.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getUserInfosFromSA(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getUserInfosFromSA(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => UserModel.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getListOfRoles(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getListOfRoles(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => RolePro.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getListOfUsersFromAdmin(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getListOfUsersFromAdmin(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => UserModel.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getThumbnailUrlsForCat(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getThumbnailUrlsForCat(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => ThumbnailOfCate.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getThumbnailCat(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getThumbnailCat(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => ThumbnailOfCate.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> addThumbnailUrlForCat(
      bytes, filePath, label, catId) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      String fileName = filePath.split('/').last;
      FormData formData = FormData.fromMap({
        "fileName": MultipartFile.fromBytes(bytes, filename: fileName),
        "label": label,
        "catId": catId,
      });
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.addThumbnailUrlForCat(), data: formData);
      return NetworkResponse.fromResponse(response,
          converter: (json) => ThumbnailUrlOfCat.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> createThumbnailCat(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.createThumbnailCat(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => ThumbnailUrlOfCat.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> updateThumbnailUrlForCat(
      bytes, filePath, label, id) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      String fileName = filePath.split('/').last;
      FormData formData = FormData.fromMap({
        "fileName": MultipartFile.fromBytes(bytes, filename: fileName),
        "label": label,
        "id": id,
      });
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .put(AppEndpoint.updateThumbnailUrlForCat(), data: formData);
      return NetworkResponse.fromResponse(response,
          converter: (json) => ThumbnailUrlOfCat.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> deleteThumbnailUrlForCat(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .delete(AppEndpoint.deleteThumbnailUrlForCat(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> setProRole(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .put(AppEndpoint.setProRole(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> v2GetProductCategories(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.v2GetProductCategories(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => ProductCategory.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> v2getProductRefByCatId(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.v2getProductRefByCatId(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => ProductReference.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> setKisblePublicThumbnailForPro(
      bytes, path, proId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      String fileName = path.split('/').last;
      FormData data = FormData.fromMap({
        'proId': proId,
        "fileName": MultipartFile.fromBytes(bytes, filename: fileName),
      });
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.setKisblePublicThumbnailForPro(), data: data);
      return NetworkResponse.fromResponse(response,
          converter: (json) => json['fileName']);
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> setThumbnailForProFromSA(bytes, path, proId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      String fileName = path.split('/').last;
      FormData data = FormData.fromMap({
        'proId': proId,
        "fileName": MultipartFile.fromBytes(bytes, filename: fileName),
      });
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.setThumbnailForProFromSA(), data: data);
      return NetworkResponse.fromResponse(response,
          converter: (json) => json['fileName']);
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> setThumbnailForUserFromSA(bytes, path, proId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      String fileName = path.split('/').last;
      FormData data = FormData.fromMap({
        'proId': proId,
        "fileName": MultipartFile.fromBytes(bytes, filename: fileName),
      });
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.setThumbnailForUserFromSA(), data: data);
      return NetworkResponse.fromResponse(response,
          converter: (json) => json['fileName']);
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getCrmStatusList(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getCrmStatusList(), queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) =>
            (json as List).map((e) => CrmStatus.fromJson(e)).toList(),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getListOfLeadsFromPro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getListOfLeadsFromPro(), queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) =>
            (json as List).map((e) => CrmLead.fromJson(e)).toList(),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> addCrmLeadsToProject(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.addCrmLeadsToProject(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> createCrmLead(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.createCrmLead(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> createCrmProjectFromPro(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.createCrmProjectFromPro(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> deleteCrmLead(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .delete(AppEndpoint.deleteCrmLead(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getCrmIntouchList(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getCrmIntouchList(), queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) =>
            (json as List).map((e) => CrmIntouch.fromJson(e)).toList(),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getListCrmProjectsFromPro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getListCrmProjectsFromPro(),
              queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) =>
            (json as List).map((e) => CrmProject.fromJson(e)).toList(),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> removeCrmLeadsToProject(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .delete(AppEndpoint.removeCrmLeadsToProject(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> setThumbnailForCrmLead(bytes, path, uuid) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      String fileName = path.split('/').last;
      FormData data = FormData.fromMap({
        'uuid': uuid,
        "fileName": MultipartFile.fromBytes(bytes, filename: fileName),
      });
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.setThumbnailForCrmLead(), data: data);
      return NetworkResponse.fromResponse(response,
          converter: (json) => json['fileName']);
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> updateCrmLead(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .put(AppEndpoint.updateCrmLead(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getCrmLeadDetails(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getCrmLeadDetails(), queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) => CrmLead.fromJson(json),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> createInTouchHistory(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.createInTouchHistory(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getCrmLeadHistory(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getCrmLeadHistory(), queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) =>
            (json as List).map((e) => CrmIntouchHistory.fromJson(e)).toList(),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getCrmProjectMemberList(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getCrmProjectMemberList(), queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) =>
            (json as List).map((e) => ProInfo.fromJson(e)).toList(),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> addCrmProjectMember(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.addCrmProjectMember(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> removeCrmProjectMember(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .delete(AppEndpoint.removeCrmProjectMember(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> marketPlaceGetProductRefByCat(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.marketPlaceGetProductRefByCat(),
              queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) =>
            (json as List).map((e) => MarketProduct.fromJson(e)).toList(),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getPaymentMethodList(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getPaymentMethodList(), queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) =>
            (json as List).map((e) => PaymentMethod.fromJson(e)).toList(),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getPaymentStatusList(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getPaymentStatusList(), queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) =>
            (json as List).map((e) => PaymentStatus.fromJson(e)).toList(),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getOrdersFromProOrUser(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getOrdersFromProOrUser(), queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) =>
            (json as List).map((e) => PaymentOrder.fromJson(e)).toList(),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getOrdersFromAdmin(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getOrdersFromAdmin(), queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) =>
            (json as List).map((e) => PaymentOrder.fromJson(e)).toList(),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> createAsOrder(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.createAsOrder(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => PaymentOrder.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> updateOrderDetailsByAdmin(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .put(AppEndpoint.updateOrderDetailsByAdmin(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> payOrder(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.payOrder(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => PaymentPayorderResult.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> addBillingInfosFromProOrUser(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.addBillingInfosFromProOrUser(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => PaymentBillingInfo.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> updateBillingInfosFromProOrUser(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .put(AppEndpoint.updateBillingInfosFromProOrUser(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> setDefaultBillingInfos(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .put(AppEndpoint.setDefaultBillingInfos(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> deleteBillingInfosFromProOrUser(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .delete(AppEndpoint.deleteBillingInfosFromProOrUser(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }

  @override
  Future<NetworkResponse> getBillingInfosFromProOrUser(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getBillingInfosFromProOrUser(),
              queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) =>
            (json as List).map((e) => PaymentBillingInfo.fromJson(e)).toList(),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getBillingInfosFromPro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getBillingInfosFromPro(), queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) =>
            (json as List).map((e) => PaymentBillingInfo.fromJson(e)).toList(),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getHomePurposeTypesList(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .get(AppEndpoint.getHomePurposeTypesList(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<HomePurposeType>((i) => HomePurposeType.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getCountriesAvailableForHomes(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false).get(
          AppEndpoint.getCountriesAvailableForHomes(),
          queryParameters: {'languageCode': appPrefs.languageCode});
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<HomeCountryAvaliable>(
                  (i) => HomeCountryAvaliable.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getHomeCatList(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .get(AppEndpoint.getHomeCatList(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<HomeCategory>((i) => HomeCategory.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getHomeDetails(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getHomeDetails(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => HomeDetailInfo.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getCurrentFiltersAvailable(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false).get(
          AppEndpoint.getCurrentFiltersAvailable(),
          queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => HomeFiltersAvailable.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getCitiesListByPurposeId(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .get(AppEndpoint.getCitiesListByPurposeId(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<HomeCity>((i) => HomeCity.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getHomesListByFilters(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getHomesListByFilters(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          prefix: '',
          converter: (json) =>
              json['numberOfResults'] ??
              (json['values'] as List<dynamic>)
                  .map<HomeDetailInfo>((i) => HomeDetailInfo.fromJson(i))
                  .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> setHomeBookmark(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .put(AppEndpoint.setHomeBookmark(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> themoviedbSearchMulti(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
        requiredToken: false,
        enableErrorHandler: false,
      ).get('https://api.themoviedb.org/3/search/multi',
          queryParameters: params);
      return NetworkResponse.fromResponse(response,
          prefix: 'results',
          converter: (json) =>
              (json as List).map((e) => TheMovieModel.fromJson(e)).toList());
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> themoviedbSearchPerson(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
        requiredToken: false,
        enableErrorHandler: false,
      ).get('https://api.themoviedb.org/3/search/person',
          queryParameters: params);
      return NetworkResponse.fromResponse(response,
          prefix: 'results',
          converter: (json) =>
              (json as List).map((e) => TheMoviePerson.fromJson(e)).toList());
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> themoviedbSearchMovie(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
        requiredToken: false,
        enableErrorHandler: false,
      ).get('https://api.themoviedb.org/3/search/movie',
          queryParameters: params);
      return NetworkResponse.fromResponse(response,
          prefix: 'results',
          converter: (json) =>
              (json as List).map((e) => TheMovieModel.fromJson(e)).toList());
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> themoviedbMovieDetail(id, params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
        requiredToken: false,
        enableErrorHandler: false,
      ).get('https://api.themoviedb.org/3/movie/$id', queryParameters: params);
      return NetworkResponse.fromResponse(response,
          prefix: '', converter: (json) => TheMovieDetail.fromJson(json));
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> themoviedbMovieReview(id, params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
        requiredToken: false,
        enableErrorHandler: false,
      ).get('https://api.themoviedb.org/3/movie/$id/reviews',
          queryParameters: params);
      return NetworkResponse.fromResponse(response,
          prefix: 'results',
          converter: (json) =>
              (json as List).map((e) => TheMovieReview.fromJson(e)).toList());
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> themoviedbTrending(
      media_type, time_window, params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
        requiredToken: false,
        enableErrorHandler: false,
      ).get('https://api.themoviedb.org/3/trending/$media_type/$time_window',
          queryParameters: params);
      return NetworkResponse.fromResponse(response,
          prefix: 'results',
          converter: (json) =>
              (json as List).map((e) => TheMovieModel.fromJson(e)).toList());
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> themoviedbDiscoverMovie(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
        requiredToken: false,
        enableErrorHandler: false,
      ).get('https://api.themoviedb.org/3/discover/movie',
          queryParameters: params);
      return NetworkResponse.fromResponse(response,
          prefix: 'results',
          converter: (json) =>
              (json as List).map((e) => TheMovieModel.fromJson(e)).toList());
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> themoviedbGenres(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
        requiredToken: false,
        enableErrorHandler: false,
      ).get('https://api.themoviedb.org/3/genre/movie/list',
          queryParameters: params);
      return NetworkResponse.fromResponse(response,
          prefix: 'genres',
          converter: (json) => (json as List)
              .map((e) => TheMovieDetailGenres.fromJson(e))
              .toList());
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> themoviedbMovieDetailCredits(id, params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
        requiredToken: false,
        enableErrorHandler: false,
      ).get('https://api.themoviedb.org/3/movie/$id/credits',
          queryParameters: params);
      return NetworkResponse.fromResponse(response,
          prefix: '', converter: (json) => TheMovieCredit.fromJson(json));
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> themoviedbMovieDetailImages(id, params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
        requiredToken: false,
        enableErrorHandler: false,
      ).get('https://api.themoviedb.org/3/movie/$id/images',
          queryParameters: params);
      return NetworkResponse.fromResponse(response,
          prefix: '', converter: (json) => TheMovieImage.fromJson(json));
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> themoviedbMovieDetailVideos(id, params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
        requiredToken: false,
        enableErrorHandler: false,
      ).get('https://api.themoviedb.org/3/movie/$id/videos',
          queryParameters: params);
      return NetworkResponse.fromResponse(response,
          prefix: 'results',
          converter: (json) =>
              (json as List).map((e) => TheMovieVideo.fromJson(e)).toList());
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> themoviedbPersonDetail(id, params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
        requiredToken: false,
        enableErrorHandler: false,
      ).get('https://api.themoviedb.org/3/person/$id', queryParameters: params);
      return NetworkResponse.fromResponse(response,
          prefix: '', converter: (json) => TheMoviePersonDetail.fromJson(json));
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> themoviedbPersonCredits(id, params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
        requiredToken: false,
        enableErrorHandler: false,
      ).get('https://api.themoviedb.org/3/person/$id/movie_credits',
          queryParameters: params);
      return NetworkResponse.fromResponse(response,
          prefix: '', converter: (json) => TheMoviePersonCredit.fromJson(json));
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> themoviedbPersonDetailImages(id, params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
        requiredToken: false,
        enableErrorHandler: false,
      ).get('https://api.themoviedb.org/3/person/$id/images',
          queryParameters: params);
      return NetworkResponse.fromResponse(response,
          prefix: '', converter: (json) => TheMoviePersonImage.fromJson(json));
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> themoviedbMovieDetailSimilar(id, params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
        requiredToken: false,
        enableErrorHandler: false,
      ).get('https://api.themoviedb.org/3/movie/$id/similar',
          queryParameters: params);
      return NetworkResponse.fromResponse(response,
          prefix: 'results',
          converter: (json) =>
              (json as List).map((e) => TheMovieModel.fromJson(e)).toList());
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> themoviedbSearchKeyword(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
        requiredToken: false,
        enableErrorHandler: false,
      ).get('https://api.themoviedb.org/3/search/keyword',
          queryParameters: params);
      return NetworkResponse.fromResponse(response,
          prefix: 'results',
          converter: (json) =>
              (json as List).map((e) => TheMovieKeyword.fromJson(e)).toList());
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> themoviedbConfigLanguage(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
        requiredToken: false,
        enableErrorHandler: false,
      ).get('https://api.themoviedb.org/3/configuration/languages',
          queryParameters: params);
      return NetworkResponse.fromResponse(response,
          prefix: '',
          converter: (json) =>
              (json as List).map((e) => TheMovieLanguage.fromJson(e)).toList());
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      appDebugPrint('catch: $e');
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getHomeCitiesList(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .get(AppEndpoint.getHomeCitiesList(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<HomeCity>((i) => HomeCity.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> createOohHome(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.createOohHome(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => HomeDetailInfo.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> updateOohHome(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .put(AppEndpoint.updateOohHome(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => HomeDetailInfo.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> setMainPicForHome(bytes, path, homeId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      String fileName = path.split('/').last;
      FormData data = FormData.fromMap({
        'homeId': homeId,
        "fileName": MultipartFile.fromBytes(bytes, filename: fileName),
      });
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.setMainPicForHome(), data: data);
      return NetworkResponse.fromResponse(response,
          converter: (json) => HomeDetailPictureUrl.fromJson(json));
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> setGalleryPicForHome(bytes, path, homeId) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      String fileName = path.split('/').last;
      FormData data = FormData.fromMap({
        'homeId': homeId,
        "fileName": MultipartFile.fromBytes(bytes, filename: fileName),
      });
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.setGalleryPicForHome(), data: data);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List)
              .map((e) => HomeDetailPictureUrl.fromJson(e))
              .toList());
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> createMovieCollection(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.createMovieCollection(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => TheMovieCollection.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> addMovieBookmarksToCollection(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.addMovieBookmarksToCollection(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> removeMovieFromCollection(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .delete(AppEndpoint.removeMovieFromCollection(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> addMovieInArckipelDb(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(AppEndpoint.addMovieInArckipelDb(), data: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => TmmAddToArckipelResult.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getMyBookmarks(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getMyBookmarks(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => TheMovieBookmark.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getMyMovieCollections(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getMyMovieCollections(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List)
              .map((e) => TheMovieCollection.fromJson(e))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> updateMovieCollection(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .put(AppEndpoint.updateMovieCollection(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getMediaForOoh(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .get(AppEndpoint.getMediaForOoh(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) =>
              (json as List).map((e) => HomePurposeMedia.fromJson(e)).toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> updateMyMovieInfos(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .put(AppEndpoint.updateMyMovieInfos(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getHomesListForUserOrPro(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getHomesListForUserOrPro(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<HomeDetailInfo>((i) => HomeDetailInfo.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getHomeBookmarkList(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getHomeBookmarkList(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<HomeDetailInfo>((i) => HomeDetailInfo.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getListOfAgencies(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .get(AppEndpoint.getListOfAgencies(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<HomeAgency>((i) => HomeAgency.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getSubscriptionState(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(AppEndpoint.getSubscriptionState(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => (json as List<dynamic>)
              .map<SubscriptionState>((i) => SubscriptionState.fromJson(i))
              .toList());
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getCurrencyOfCountry(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(requiredToken: false)
          .get(AppEndpoint.getCurrencyOfCountry(), queryParameters: params);
      return NetworkResponse.fromResponse(response,
          converter: (json) => CurrencyOfCountry.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> removeGalleryPicForHome(params) async {
    bool isDisconnect = await WifiService.isDisconnect();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClientsWeb(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .delete(AppEndpoint.removeGalleryPicForHome(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    }
  }
}
